% Auto-generated chapter 7 for ibnmajah
% Hadiths in this chapter: 145

\hadithdefcmd{ibnmajah}{1638}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، وَوَكِيعٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ: قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ كُلُّ عَمَلِ ابْنِ آدَمَ يُضَاعَفُ الْحَسَنَةُ بِعَشْرِ أَمْثَالِهَا إِلَى سَبْعِمِائَةِ ضِعْفٍ إِلَى مَا شَاءَ اللَّهُ. يَقُولُ اللَّهُ: إِلاَّ الصَّوْمَ فَإِنَّهُ لِي وَأَنَا أَجْزِي بِهِ. يَدَعُ شَهْوَتَهُ وَطَعَامَهُ مِنْ أَجْلِي. لِلصَّائِمِ فَرْحَتَانِ: فَرْحَةٌ عِنْدَ فِطْرِهِ وَفَرْحَةٌ عِنْدَ لِقَاءِ رَبِّهِ. وَلَخُلُوفُ فَمِ الصَّائِمِ أَطْيَبُ عِنْدَ اللَّهِ مِنْ رِيحِ الْمِسْكِ ‏"‏ ‏.‏\hadithno{1638}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“Every good deed of the son of Adam will be multiplied manifold. A good deed will be multiplied ten times up to as many as seven hundred times, or as much as Allah wills. Allah says: ‘Except for fasting, which is for Me and I shall reward for it. He gives up his desire and his food for My sake.’ The fasting person has two joys, one when he breaks his fast and another when he meets his Lord. The smell that comes from the mouth of a fasting person is better before Allah than the fragrance of musk.”}}
\hadithdefcmd{ibnmajah}{1639}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ الْمِصْرِيُّ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ سَعِيدِ بْنِ أَبِي هِنْدٍ، أَنَّ مُطَرِّفًا، مِنْ بَنِي عَامِرِ بْنِ صَعْصَعَةَ حَدَّثَهُ أَنَّ عُثْمَانَ بْنَ أَبِي الْعَاصِ الثَّقَفِيَّ دَعَا لَهُ بِلَبَنٍ يَسْقِيهِ فَقَالَ مُطَرِّفٌ: إِنِّي صَائِمٌ ‏.‏ فَقَالَ عُثْمَانُ: سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ: ‏ "‏ الصِّيَامُ جُنَّةٌ مِنَ النَّارِ كَجُنَّةِ أَحَدِكُمْ مِنَ الْقِتَالِ ‏"‏ ‏.‏\hadithno{1639}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Mutarrif, from the tribe of Banu ‘Amir bin Sa’sa’ah narrated that ‘Uthman bin Abul-‘As Ath-Thaqafi invited him to drink some milk that he poured for him. Mutarrif said:“I am fasting.” ‘Uthman said: “I heard the Messenger of Allah (ﷺ) say: ‘Fasting is a shield against the Fire just like the shield of anyone of you against fighting.’”}}
\hadithdefcmd{ibnmajah}{1640}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، حَدَّثَنِي هِشَامُ بْنُ سَعْدٍ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ: ‏ "‏ إِنَّ فِي الْجَنَّةِ بَابًا يُقَالُ لَهُ الرَّيَّانُ يُدْعَى يَوْمَ الْقِيَامَةِ يُقَالُ: أَيْنَ الصَّائِمُونَ؟ فَمَنْ كَانَ مِنَ الصَّائِمِينَ دَخَلَهُ وَمَنْ دَخَلَهُ لَمْ يَظْمَأْ أَبَدًا ‏"‏ ‏.‏\hadithno{1640}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Sahl bin Sa’d that the Prophet (ﷺ) said:“In Paradise there is a gate called Rayyan. On the Day of Resurrection the call will go out saying: ‘Where are those who used to fast?’ Whoever is among those who used to fast will enter it, and whoever enters it will never experience thirst again.”}}
\hadithdefcmd{ibnmajah}{1641}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ: قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ صَامَ رَمَضَانَ إِيمَانًا وَاحْتِسَابًا غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏\hadithno{1641}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:‘Whoever fasts Ramadan out of faith and the hope of reward will be forgiven his previous sins.”}}
\hadithdefcmd{ibnmajah}{1642}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ: ‏ "‏ إِذَا كَانَتْ أَوَّلُ لَيْلَةٍ مِنْ رَمَضَانَ صُفِّدَتِ الشَّيَاطِينُ وَمَرَدَةُ الْجِنِّ وَغُلِّقَتْ أَبْوَابُ النَّارِ فَلَمْ يُفْتَحْ مِنْهَا بَابٌ. وَفُتِحَتْ أَبْوَابُ الْجَنَّةِ فَلَمْ يُغْلَقْ مِنْهَا بَابٌ. وَنَادَى مُنَادٍ: يَا بَاغِيَ الْخَيْرِ أَقْبِلْ. وَيَا بَاغِيَ الشَّرِّ أَقْصِرْ. وَلِلَّهِ عُتَقَاءُ مِنَ النَّارِ. وَذَلِكَ فِي كُلِّ لَيْلَةٍ ‏"‏ ‏.‏\hadithno{1642}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“When the first night of Ramadan comes, the satans and mischievous jinns are chained up, and the gates of the Fire are closed, and none of its gates are opened. The gates of Paradise are opened and none of its gates are closed. And a caller cries out: ‘O seeker of good, proceed, O seeker of evil, stop.’ And Allah has necks (people) whom He frees (from the Fire), and that happens every day.”}}
\hadithdefcmd{ibnmajah}{1643}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنِ الأَعْمَشِ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ لِلَّهِ عِنْدَ كُلِّ فِطْرٍ عُتَقَاءَ وَذَلِكَ فِي كُلِّ لَيْلَةٍ ‏"‏ ‏.‏\hadithno{1643}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Jabir that the Messenger of Allah (ﷺ) said:“At every breaking of the fast Allah has people whom He frees (from the Fire), and that happens every night.”}}
\hadithdefcmd{ibnmajah}{1644}{حَدَّثَنَا أَبُو بَدْرٍ، عَبَّادُ بْنُ الْوَلِيدِ حَدَّثَنَا مُحَمَّدُ بْنُ بِلاَلٍ، حَدَّثَنَا عِمْرَانُ الْقَطَّانُ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ: دَخَلَ رَمَضَانُ. فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ هَذَا الشَّهْرَ قَدْ حَضَرَكُمْ وَفِيهِ لَيْلَةٌ خَيْرٌ مِنْ أَلْفِ شَهْرٍ مَنْ حُرِمَهَا فَقَدْ حُرِمَ الْخَيْرَ كُلَّهُ وَلاَ يُحْرَمُ خَيْرَهَا إِلاَّ مَحْرُومٌ ‏"‏ ‏.‏\hadithno{1644}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Anas bin Malik said:“Ramadan began, and the Messenger of Allah (ﷺ) said: ‘This month has come to you, and in it there is a night that is better than a thousand months. Whoever is deprived of it is deprived of all goodness, and no one is deprived of its goodness except one who is truly deprived.’”}}
\hadithdefcmd{ibnmajah}{1645}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنْ عَمْرِو بْنِ قَيْسٍ، عَنْ أَبِي إِسْحَاقَ، عَنْ صِلَةَ بْنِ زُفَرَ، قَالَ كُنَّا عِنْدَ عَمَّارٍ فِي الْيَوْمِ الَّذِي يُشَكُّ فِيهِ فَأُتِيَ بِشَاةٍ فَتَنَحَّى بَعْضُ الْقَوْمِ فَقَالَ عَمَّارٌ مَنْ صَامَ هَذَا الْيَوْمَ فَقَدْ عَصَى أَبَا الْقَاسِمِ ـ صلى الله عليه وسلم ـ ‏.‏\hadithno{1645}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Silah bin Zufar said:“We were with ‘Ammar on the day concerning which there was some doubt. A (roasted) sheep was brought and some of the people moved away. ‘Ammar said: ‘Whoever is fasting on this day has disobeyed Abu Qasim (ﷺ).’”}}
\hadithdefcmd{ibnmajah}{1646}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، عَنْ عَبْدِ اللَّهِ بْنِ سَعِيدٍ، عَنْ جَدِّهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنْ تَعْجِيلِ صَوْمِ يَوْمٍ قَبْلَ الرُّؤْيَةِ ‏.‏\hadithno{1646}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:“The Messenger of Allah (ﷺ) forbade anticipating the fast by fasting one day before sighting (of the crescent).”}}
\hadithdefcmd{ibnmajah}{1647}{حَدَّثَنَا الْعَبَّاسُ بْنُ الْوَلِيدِ الدِّمَشْقِيُّ، حَدَّثَنَا مَرْوَانُ بْنُ مُحَمَّدٍ، حَدَّثَنَا الْهَيْثَمُ بْنُ حُمَيْدٍ، حَدَّثَنَا الْعَلاَءُ بْنُ الْحَارِثِ، عَنِ الْقَاسِمِ أَبِي عَبْدِ الرَّحْمَنِ، أَنَّهُ سَمِعَ مُعَاوِيَةَ بْنَ أَبِي سُفْيَانَ، عَلَى الْمِنْبَرِ يَقُولُ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ عَلَى الْمِنْبَرِ قَبْلَ شَهْرِ رَمَضَانَ ‏ "‏ الصِّيَامُ يَوْمَ كَذَا وَكَذَا وَنَحْنُ مُتَقَدِّمُونَ فَمَنْ شَاءَ فَلْيَتَقَدَّمْ وَمَنْ شَاءَ فَلْيَتَأَخَّرْ ‏"‏ ‏.‏\hadithno{1647}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Qasim Abu ‘Abdur-Rahman that he heard Mu’awiyah bin Abu Sufyan on the pulpit saying:“The Messenger of Allah (ﷺ) used to say from the pulpit, before the month of Ramadan: ‘Fasting will begin on such and such a day, but we are going to start fasting earlier, so whoever wants to start fasting earlier (i.e., in Sha’ban), let him do so, and whoever wants to wait until Ramadan begins, let him do so.’”}}
\hadithdefcmd{ibnmajah}{1648}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، عَنْ شُعْبَةَ، عَنْ مَنْصُورٍ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ أَبِي سَلَمَةَ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَصِلُ شَعْبَانَ بِرَمَضَانَ ‏.‏\hadithno{1648}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Umm Salamah said:“The Messenger of Allah (ﷺ) used to join Sha’ban to Ramadan.”}}
\hadithdefcmd{ibnmajah}{1649}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا يَحْيَى بْنُ حَمْزَةَ، حَدَّثَنِي ثَوْرُ بْنُ يَزِيدَ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنْ رَبِيعَةَ بْنِ الْغَازِ، أَنَّهُ سَأَلَ عَائِشَةَ عَنْ صِيَامِ، رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَتْ: كَانَ يَصُومُ شَعْبَانَ كُلَّهُ حَتَّى يَصِلَهُ بِرَمَضَانَ ‏.‏\hadithno{1649}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Rabi’ah bin Ghaz asked ‘Aishah about the fasting of the Messenger of Allah (ﷺ). She said:“He used to fast all of Sha’ban, until he joined it to Ramadan.”}}
\hadithdefcmd{ibnmajah}{1650}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ حَبِيبٍ، وَالْوَلِيدُ بْنُ مُسْلِمٍ، عَنِ الأَوْزَاعِيِّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ: قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ تَقَدَّمُوا صِيَامَ رَمَضَانَ بِيَوْمٍ وَلاَ بِيَوْمَيْنِ إِلاَّ رَجُلٌ كَانَ يَصُومُ صَوْمًا فَيَصُومُهُ ‏"‏ ‏.‏\hadithno{1650}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:‘Do not anticipate Ramadan by fasting one or two days before, except for a man who has a habitual pattern of fasting, in which case let him fast.”}}
\hadithdefcmd{ibnmajah}{1651}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، ح وَحَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا مُسْلِمُ بْنُ خَالِدٍ، قَال: حَدَّثَنَا الْعَلاَءُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ: قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا كَانَ النِّصْفُ مِنْ شَعْبَانَ فَلاَ صَوْمَ حَتَّى يَجِيءَ رَمَضَانُ ‏"‏ ‏.‏\hadithno{1651}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:‘When it is the middle of Sha’ban, do not fast until Ramadan comes.”}}
\hadithdefcmd{ibnmajah}{1652}{حَدَّثَنَا عَمْرُو بْنُ عَبْدِ اللَّهِ الأَوْدِيُّ، وَمُحَمَّدُ بْنُ إِسْمَاعِيلَ، قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا زَائِدَةُ بْنُ قُدَامَةَ، حَدَّثَنَا سِمَاكُ بْنُ حَرْبٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ جَاءَ أَعْرَابِيٌّ إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ فَقَالَ أَبْصَرْتُ الْهِلاَلَ اللَّيْلَةَ ‏.‏ فَقَالَ: ‏"‏ أَتَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنَّ مُحَمَّدًا رَسُولُ اللَّهِ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ: ‏"‏ قُمْ يَا بِلاَلُ فَأَذِّنْ فِي النَّاسِ أَنْ يَصُومُوا غَدًا ‏"‏ ‏.‏\hadithno{1652}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn ‘Abbas said:“A Bedouin came to the Prophet (ﷺ) and said: ‘I have seen the new crescent tonight.’ He said: ‘Do you bear witness that none has the right to be worshipped but Allah and that Muhammad is the Messenger of Allah (ﷺ)?’ He said: ‘Yes.’ He said: ‘Get up, O Bilal, and announce to the people that they should fast tomorrow.’” Abu 'Ali said: "This is how it was narrated from Walid bin Abu Thawr and Hasan bin 'Ali. It was also narrated from Hammad bin Salamah, but he did not mention Ibn 'Abbas. He said: 'And he announced that they should perform the prayer and that they should fast}}
\hadithdefcmd{ibnmajah}{1653}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا هُشَيْمٌ، عَنْ أَبِي بِشْرٍ، عَنْ أَبِي عُمَيْرِ بْنِ أَنَسِ بْنِ مَالِكٍ، قَالَ حَدَّثَنِي عُمُومَتِي، مِنَ الأَنْصَارِ مِنْ أَصْحَابِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَالُوا: أُغْمِيَ عَلَيْنَا هِلاَلُ شَوَّالٍ. فَأَصْبَحْنَا صِيَامًا. فَجَاءَ رَكْبٌ مِنْ آخِرِ النَّهَارِ فَشَهِدُوا عِنْدَ النَّبِيِّ ـ صلى الله عليه وسلم ـ أَنَّهُمْ رَأَوُا الْهِلاَلَ بِالأَمْسِ. فَأَمَرَهُمْ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَنْ يُفْطِرُوا وَأَنْ يَخْرُجُوا إِلَى عِيدِهِمْ مِنَ الْغَدِ ‏.‏\hadithno{1653}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that ‘Umair bin Anas bin Malik said:“My paternal uncles among the Ansar who were among the Companions of the Messenger of Allah (ﷺ) told me: ‘The new crescent of Shawwal was covered with clouds, so we fasted the next day. Then some riders came at the end of the day and testified to the Prophet (ﷺ) that they had seen the new crescent the night before. The Messenger of Allah (ﷺ) commanded them to break their fast and to go out to offer the ‘Eid prayer the following morning.’”}}
\hadithdefcmd{ibnmajah}{1654}{حَدَّثَنَا أَبُو مَرْوَانَ، مُحَمَّدُ بْنُ عُثْمَانَ الْعُثْمَانِيُّ حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عُمَرَ، قَالَ: قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا رَأَيْتُمُ الْهِلاَلَ فَصُومُوا وَإِذَا رَأَيْتُمُوهُ فَأَفْطِرُوا ‏.‏ فَإِنْ غُمَّ عَلَيْكُمْ فَاقْدُرُوا لَهُ ‏"‏ ‏.‏ وَكَانَ ابْنُ عُمَرَ يَصُومُ قَبْلَ الْهِلاَلِ بِيَوْمٍ ‏.‏\hadithno{1654}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Ibn ‘Umar that the Messenger of Allah (ﷺ) said:‘When you see the new crescent, fast, and when you see it, stop fasting. If it is cloudy then calculate it (as thirty days).” Ibn ‘Umar used to fast one day before the new crescent was seen}}
\hadithdefcmd{ibnmajah}{1655}{حَدَّثَنَا أَبُو مَرْوَانَ الْعُثْمَانِيُّ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ: قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا رَأَيْتُمُ الْهِلاَلَ فَصُومُوا وَإِذَا رَأَيْتُمُوهُ فَأَفْطِرُوا فَإِنْ غُمَّ عَلَيْكُمْ فَصُومُوا ثَلاَثِينَ يَوْمًا ‏"‏ ‏.‏\hadithno{1655}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“When you see the new crescent then fast, and when you see it then stop fasting. If it is cloudy then fast thirty days.”}}
\hadithdefcmd{ibnmajah}{1656}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ: قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ كَمْ مَضَى مِنَ الشَّهْرِ؟ ‏"‏ ‏.‏ قَالَ: قُلْنَا: اثْنَانِ وَعِشْرُونَ وَبَقِيَتْ ثَمَانٍ ‏.‏ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ الشَّهْرُ هَكَذَا وَالشَّهْرُ هَكَذَا وَالشَّهْرُ هَكَذَا ‏"‏ ‏.‏ ثَلاَثَ مَرَّاتٍ وَأَمْسَكَ وَاحِدَةً ‏.‏\hadithno{1656}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:‘How much of the month has passed?” We said: “Twenty-two (days), and there are eight left.” The Messenger of Allah (ﷺ) said: “The month is like that, and the month is like that, (and the month is like that), three times, and he withheld one finger the last time.”}}
\hadithdefcmd{ibnmajah}{1657}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، عَنْ مُحَمَّدِ بْنِ سَعْدِ بْنِ أَبِي وَقَّاصٍ، عَنْ أَبِيهِ، قَالَ: قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الشَّهْرُ هَكَذَا وَهَكَذَا وَهَكَذَا ‏"‏ ‏.‏ وَعَقَدَ تِسْعًا وَعِشْرِينَ فِي الثَّالِثَةِ ‏.‏\hadithno{1657}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Muhammad bin Sa’d bin Abu Waqqas that his father said:“The Messenger of Allah (ﷺ) said: ‘The month is like that and like that and like that,’ and he showed nine fingers on the third time to indicate twenty-nine.”}}
\hadithdefcmd{ibnmajah}{1658}{حَدَّثَنَا مُجَاهِدُ بْنُ مُوسَى، حَدَّثَنَا الْقَاسِمُ بْنُ مَالِكٍ الْمُزَنِيُّ، حَدَّثَنَا الْجُرَيْرِيُّ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ: مَا صُمْنَا عَلَى عَهْدِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ تِسْعًا وَعِشْرِينَ أَكْثَرُ مِمَّا صُمْنَا ثَلاَثِينَ ‏.‏\hadithno{1658}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:"(The months in which) We fasted twenty-nine days at the time of the Messenger of Allah (ﷺ), were more than (the months in which) we fasted thirty days}}
\hadithdefcmd{ibnmajah}{1659}{حَدَّثَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا خَالِدٌ الْحَذَّاءُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرَةَ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ: ‏ "‏ شَهْرَا عِيدٍ لاَ يَنْقُصَانِ رَمَضَانُ وَذُو الْحِجَّةِ ‏"‏ ‏.‏\hadithno{1659}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that from ‘Abdur-Rahman bin Abu Bakrah, from his father, that the Prophet (ﷺ) said:“Two months of ‘Eid whose reward cannot be reduced (even if they are twenty-nine days): ‘Ramadan and Dhul-Hijjah.”}}
\hadithdefcmd{ibnmajah}{1660}{حَدَّثَنَا مُحَمَّدُ بْنُ عُمَرَ بْنِ أَبِي عُمَرَ الْمُقْرِئُ، حَدَّثَنَا إِسْحَاقُ بْنُ عِيسَى، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ: قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الْفِطْرُ يَوْمَ تُفْطِرُونَ وَالأَضْحَى يَوْمَ تُضَحُّونَ ‏"‏ ‏.‏\hadithno{1660}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“Al-Fitr is the day when you break your fast and Al-Adha is the day when you offer sacrifices.”}}
\hadithdefcmd{ibnmajah}{1661}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ مَنْصُورٍ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ صَامَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فِي السَّفَرِ وَأَفْطَرَ ‏.‏\hadithno{1661}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn ‘Abbas said:“The Messenger of Allah (ﷺ) fasted while he was traveling, and he broke his fast.”}}
\hadithdefcmd{ibnmajah}{1662}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ: سَأَلَ حَمْزَةُ الأَسْلَمِيُّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ: إِنِّي أَصُومُ أَفَأَصُومُ فِي السَّفَرِ؟ فَقَالَ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنْ شِئْتَ فَصُمْ وَإِنْ شِئْتَ فَأَفْطِرْ ‏"‏ ‏.‏\hadithno{1662}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that ‘Aishah said:“Hamzah Al-Aslami asked the Messenger of Allah (ﷺ): ‘I am fasting, should I fast while traveling?’ The Messenger of Allah (ﷺ) said: ‘If you wish, then fast, and if you wish, then break your fast.’”}}
\hadithdefcmd{ibnmajah}{1663}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو عَامِرٍ، ح وَحَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ، وَهَارُونُ بْنُ عَبْدِ اللَّهِ الْحَمَّالُ، قَالاَ: حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، جَمِيعًا عَنْ هِشَامِ بْنِ سَعْدٍ، عَنْ عُثْمَانَ بْنِ حَيَّانَ الدِّمَشْقِيِّ، حَدَّثَتْنِي أُمُّ الدَّرْدَاءِ، عَنْ أَبِي الدَّرْدَاءِ، أَنَّهُ قَالَ: لَقَدْ رَأَيْتُنَا مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فِي بَعْضِ أَسْفَارِهِ فِي الْيَوْمِ الْحَارِّ.الشَّدِيدِ الْحَرِّ. وَإِنَّ الرَّجُلَ لَيَضَعُ يَدَهُ عَلَى رَأْسِهِ مِنْ شِدَّةِ الْحَرِّ. وَمَا فِي الْقَوْمِ أَحَدٌ صَائِمٌ إِلاَّ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَعَبْدُ اللَّهِ بْنُ رَوَاحَةَ ‏.‏\hadithno{1663}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Darda’ said:“We were with the Messenger of Allah (ﷺ) on one of his journeys on a hot day, and it was extremely hot. A man would put his hand over his head because of the intense heat. No one among the people was fasting except for the Messenger of Allah (ﷺ) and ‘Abdullah bin Rawahah.”}}
\hadithdefcmd{ibnmajah}{1664}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ الصَّبَّاحِ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ صَفْوَانَ بْنِ عَبْدِ اللَّهِ، عَنْ أُمِّ الدَّرْدَاءِ، عَنْ كَعْبِ بْنِ عَاصِمٍ، قَالَ: قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لَيْسَ مِنَ الْبِرِّ الصِّيَامُ فِي السَّفَرِ ‏"‏ ‏.‏\hadithno{1664}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ka’b bin ‘Asim that the Messenger of Allah (ﷺ) said:‘It is not an act of righteousness to fast while traveling.”}}
\hadithdefcmd{ibnmajah}{1665}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُصَفَّى الْحِمْصِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ حَرْبٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ: قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لَيْسَ مِنَ الْبِرِّ الصِّيَامُ فِي السَّفَرِ ‏"‏ ‏.‏\hadithno{1665}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn ‘Umar that the Messenger of Allah (ﷺ) said:"It is not an act of righteousness to fast while traveling}}
\hadithdefcmd{ibnmajah}{1666}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ الْحِزَامِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُوسَى التَّيْمِيُّ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، قَالَ: قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ صَائِمُ رَمَضَانَ فِي السَّفَرِ كَالْمُفْطِرِ فِي الْحَضَرِ ‏"‏ ‏.قالَ أَبُو إِسْحاقَ: هَذاالْحَديثُ لَيْسَ بِشَيْءٍ\hadithno{1666}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Abdur-Rahman bin ‘Awf that the Messenger of Allah (ﷺ) said:“The one who fasts Ramadan while traveling is like one who breaks his fast when not traveling.” Abu Ishaq said: "This Hadith is of no significance}}
\hadithdefcmd{ibnmajah}{1667}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ: حَدَّثَنَا وَكِيعٌ، عَنْ أَبِي هِلاَلٍ، عَنْ عَبْدِ اللَّهِ بْنِ سَوَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، - رَجُلٌ مِنْ بَنِي عَبْدِ الأَشْهَلِ وَقَالَ: عَلِيُّ بْنُ مُحَمَّدٍ مِنْ بَنِي عَبْدِ اللَّهِ بْنِ كَعْبٍ - قَالَ: أَغَارَتْ عَلَيْنَا خَيْلُ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَأَتَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ وَهُوَ يَتَغَدَّى فَقَالَ: ‏"‏ ادْنُ فَكُلْ ‏"‏ ‏.‏ قُلْتُ: إِنِّي صَائِمٌ ‏.‏ قَالَ: ‏"‏ اجْلِسْ أُحَدِّثْكَ عَنِ الصَّوْمِ أَوِ الصِّيَامِ ‏.‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ وَضَعَ عَنِ الْمُسَافِرِ شَطْرَ الصَّلاَةِ وَعَنِ الْمُسَافِرِ وَالْحَامِلِ وَالْمُرْضِعِ الصَّوْمَ أَوِ الصِّيَامَ ‏"‏ ‏.‏ وَاللَّهِ لَقَدْ قَالَهُمَا النَّبِيُّ ـ صلى الله عليه وسلم ـ كِلْتَاهُمَا أَوْ إِحْدَاهُمَا فَيَا لَهْفَ نَفْسِي فَهَلاَّ كُنْتُ طَعِمْتُ مِنْ طَعَامِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏\hadithno{1667}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Anas bin Malik that a man from the tribe of Banu ‘Abdul-Ashhal, while (one narrator) ‘Ali bin Muhammad said (he was) a man from the tribe of Banu ‘Abdullah bin Ka’b, said:“The cavalry of the Messenger of Allah (ﷺ) attacked us, so I came to the Messenger of Allah (ﷺ) while he was eating a meal. He said: ‘Come and eat.’ I said: ‘I am fasting.’ He said: ‘Sit down and I will tell you about fasting. Allah has relieved the traveler of half of the prayer, and He has relieved the traveler, the pregnant, and the nursing mothers of the duty to fast.’ By Allah, the Prophet (ﷺ) said them, both, or one of them, and now I feel so disappointed that I had not eaten of the food of the Messenger of Allah (ﷺ).”}}
\hadithdefcmd{ibnmajah}{1668}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ الدِّمَشْقِيُّ، حَدَّثَنَا الرَّبِيعُ بْنُ بَدْرٍ، عَنِ الْجُرَيْرِيِّ، عَنِ الْحَسَنِ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ رَخَّصَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ لِلْحُبْلَى الَّتِي تَخَافُ عَلَى نَفْسِهَا أَنْ تُفْطِرَ وَلِلْمُرْضِعِ الَّتِي تَخَافُ عَلَى وَلَدِهَا ‏.‏\hadithno{1668}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Anas bin Malik said:“The Messenger of Allah (ﷺ) granted a concession to pregnant women who fear for themselves, allowing them not to fast, and to nursing mothers who fear for their infants.”}}
\hadithdefcmd{ibnmajah}{1669}{حَدَّثَنَا عَلِيُّ بْنُ الْمُنْذِرِ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، وَعَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ أَبِي سَلَمَةَ، قَالَ: سَمِعْتُ عَائِشَةَ تَقُولُ: إِنْ كَانَ لَيَكُونُ عَلَىَّ الصِّيَامُ مِنْ شَهْرِ رَمَضَانَ فَمَا أَقْضِيهِ حَتَّى يَجِيءَ شَعْبَانُ ‏.‏\hadithno{1669}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Abu Salamah said:“I heard ‘Aishah say: ‘I used to owe fasts from the month of Ramadan, and I would not make them up for until Sha’ban came.’”}}
\hadithdefcmd{ibnmajah}{1670}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ عُبَيْدَةَ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ: كُنَّا نَحِيضُ عِنْدَ النَّبِيِّ ـ صلى الله عليه وسلم ـ فَيَأْمُرُنَا بِقَضَاءِ الصَّوْمِ ‏.‏\hadithno{1670}\hadithgrade{Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that ‘Aishah said:“We used to menstruate at the time of the Prophet (ﷺ), and he would order us to make up for the (missed) fasts.’”}}
\hadithdefcmd{ibnmajah}{1671}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ: أَتَى النَّبِيَّ ـ صلى الله عليه وسلم ـ رَجُلٌ فَقَالَ هَلَكْتُ ‏.‏ قَالَ: ‏"‏ وَمَا أَهْلَكَكَ؟ ‏"‏ ‏.‏ قَالَ: وَقَعْتُ عَلَى امْرَأَتِي فِي رَمَضَانَ ‏.‏ فَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏"‏ أَعْتِقْ رَقَبَةً ‏"‏ ‏.‏ قَالَ: لاَ أَجِدُهَا ‏.‏ قَالَ: ‏"‏ صُمْ شَهْرَيْنِ مُتَتَابِعَيْنِ ‏"‏ ‏.‏ قَالَ: لاَ أُطِيقُ ‏.‏ قَالَ: ‏"‏ أَطْعِمْ سِتِّينَ مِسْكِينًا ‏"‏ ‏.‏ قَالَ: لاَ أَجِدُ ‏.‏ قَالَ: ‏"‏ اجْلِسْ ‏"‏ ‏.‏ فَجَلَسَ فَبَيْنَمَا هُوَ كَذَلِكَ إِذْ أُتِيَ بِمِكْتَلٍ يُدْعَى الْعَرَقَ فَقَالَ: ‏"‏ اذْهَبْ فَتَصَدَّقْ بِهِ ‏"‏ قَالَ: يَا رَسُولَ اللَّهِ وَالَّذِي بَعَثَكَ بِالْحَقِّ مَا بَيْنَ لاَبَتَيْهَا أَهْلُ بَيْتٍ أَحْوَجُ إِلَيْهِ مِنَّا ‏.‏ قَالَ: ‏"‏ فَانْطَلِقْ فَأَطْعِمْهُ عِيَالَكَ ‏"‏ ‏.‏ حَدَّثَنَا حَرْمَلَةُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، حَدَّثَنَا عَبْدُ الْجَبَّارِ بْنُ عُمَرَ، حَدَّثَنِي يَحْيَى بْنُ سَعِيدٍ، عَنِ ابْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ بِذَلِكَ فَقَالَ: ‏"‏ وَصُمْ يَوْمًا مَكَانَهُ ‏"‏ ‏.‏\hadithno{1671}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Abu Hurairah said:“A man came to the Prophet (ﷺ) and said: ‘I am doomed.’ He said: ‘Why are you doomed?’ He said: ‘I had intercourse with my wife in Ramadan.’ The Prophet (ﷺ) said: ‘Free a slave.’ He said: ‘I cannot.’ He said: ‘Fast for two consecutive months.’ He said: ‘I cannot.’ He said: ‘Feed sixty poor persons.’ He said: ‘I cannot.’ He said: ‘Sit down.’ So he sat down, and while doing so a basketful of dates was brought. The Prophet (ﷺ) said: ‘Go and give this in charity.’ He said: ‘O Messenger of Allah, by the One Who sent you with the truth, there is no household between its two lava fields (i.e., in Al-Madinah) that is more in need of it than us.’ He said: ‘Then go and feed your family.’” Another chain from Abu Hurairah with additional words: "Then he (the Prophet SAW) said: "And fast a day in its place}}
\hadithdefcmd{ibnmajah}{1672}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنِ ابْنِ الْمُطَوِّسِ، عَنْ أَبِيهِ الْمُطَوِّسِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ: قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ أَفْطَرَ يَوْمًا مِنْ رَمَضَانَ مِنْ غَيْرِ رُخْصَةٍ لَمْ يُجْزِهِ صِيَامُ الدَّهْرِ ‏"‏ ‏.‏\hadithno{1672}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“Whoever does not fast one day in Ramadan without having a concession allowing that, fasting for a lifetime will not make up for that.”}}
\hadithdefcmd{ibnmajah}{1673}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ عَوْفٍ، عَنْ خِلاَسٍ، وَمُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ: قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ أَكَلَ نَاسِيًا وَهُوَ صَائِمٌ فَلْيُتِمَّ صَوْمَهُ فَإِنَّمَا أَطْعَمَهُ اللَّهُ وَسَقَاهُ ‏"‏ ‏.‏\hadithno{1673}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:"Whoever eats out of forgetfulness while fasting, let him complete his fast, for it is Allah Who has fed him and given him to drink}}
\hadithdefcmd{ibnmajah}{1674}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ فَاطِمَةَ بِنْتِ الْمُنْذِرِ، عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ، قَالَتْ: أَفْطَرْنَا عَلَى عَهْدِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فِي يَوْمِ غَيْمٍ ثُمَّ طَلَعَتِ الشَّمْسُ ‏.‏ قُلْتُ لِهِشَامٍ: أُمِرُوا بِالْقَضَاءِ؟ قَالَ: لاَ بُدَّ مِنْ ذَلِكَ ‏.‏\hadithno{1674}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Asma’ bint Abu Bakr said:“We broke our fast on a cloudy day at the time of the Messenger of Allah (ﷺ), then the sun appeared.” I (one of the narrators) said to Hisham: "Were they commanded to make up for that day?" He said: "It had to be made up." (According to Hisham's opinion)}}
\hadithdefcmd{ibnmajah}{1675}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَعْلَى، وَمُحَمَّدُ، ابْنَا عُبَيْدٍ الطَّنَافِسِيِّ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ إِسْحَاقَ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ أَبِي مَرْزُوقٍ، قَالَ: سَمِعْتُ فَضَالَةَ بْنَ عُبَيْدٍ الأَنْصَارِيَّ، يُحَدِّثُ أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ خَرَجَ عَلَيْهِمْ فِي يَوْمٍ كَانَ يَصُومُهُ فَدَعَا بِإِنَاءٍ فَشَرِبَ فَقُلْنَا: يَا رَسُولَ اللَّهِ إِنَّ هَذَا يَوْمٌ كُنْتَ تَصُومُهُ ‏.‏ قَالَ: ‏ "‏ أَجَلْ. وَلَكِنِّي قِئْتُ ‏"‏ ‏.‏\hadithno{1675}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Masruq said:“I heard Fadalah bin ‘Ubaid Al- Ansari narrating that the Prophet (ﷺ) came out to them on a day when he was fasting. He called for a vessel and drank. We said: ‘O Messenger of Allah, you were fasting today.’ He said: ‘Yes, but I vomited.’”}}
\hadithdefcmd{ibnmajah}{1676}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عَبْدِ الْكَرِيمِ، حَدَّثَنَا الْحَكَمُ بْنُ مُوسَى، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، ح وَحَدَّثَنَا عُبَيْدُ اللَّهِ، حَدَّثَنَا عَلِيُّ بْنُ الْحَسَنِ بْنِ سُلَيْمَانَ أَبُو الشَّعْثَاءِ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، جَمِيعًا عَنْ هِشَامٍ، عَنِ ابْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ: ‏ "‏ مَنْ ذَرَعَهُ الْقَىْءُ فَلاَ قَضَاءَ عَلَيْهِ وَمَنِ اسْتَقَاءَ فَعَلَيْهِ الْقَضَاءُ ‏"‏ ‏.‏\hadithno{1676}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:“Whoever unintentionally vomits, he does not have to make up for the fast, but whoever makes himself vomit, has to make up for the fast.”}}
\hadithdefcmd{ibnmajah}{1677}{حَدَّثَنَا عُثْمَانُ بْنُ مُحَمَّدِ بْنِ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو إِسْمَاعِيلَ الْمُؤَدِّبُ، عَنْ مُجَالِدٍ، عَنِ الشَّعْبِيِّ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ: قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مِنْ خَيْرِ خِصَالِ الصَّائِمِ السِّوَاكُ ‏"‏ ‏.‏\hadithno{1677}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Aishah that the Messenger of Allah (ﷺ) said:“One of the best actions of the fasting person is using the tooth stick.”}}
\hadithdefcmd{ibnmajah}{1678}{حَدَّثَنَا أَبُو التَّقِيِّ، هِشَامُ بْنُ عَبْدِ الْمَلِكِ الْحِمْصِيُّ حَدَّثَنَا بَقِيَّةُ، حَدَّثَنَا الزُّبَيْدِيُّ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتِ: اكْتَحَلَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَهُوَ صَائِمٌ ‏.‏\hadithno{1678}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Aishah said:“The Messenger of Allah (ﷺ) applied kohl to his eyes while he was fasting.”}}
\hadithdefcmd{ibnmajah}{1679}{حَدَّثَنَا أَيُّوبُ بْنُ مُحَمَّدٍ الرَّقِّيُّ، وَدَاوُدُ بْنُ رُشَيْدٍ، قَالاَ حَدَّثَنَا مُعَمَّرُ بْنُ سُلَيْمَانَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ بِشْرٍ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ: قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أَفْطَرَ الْحَاجِمُ وَالْمَحْجُومُ ‏"‏ ‏.‏\hadithno{1679}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:‘The cupper and the one for whom cupping is done both break their fast.”}}
\hadithdefcmd{ibnmajah}{1680}{حَدَّثَنَا أَحْمَدُ بْنُ يُوسُفَ السُّلَمِيُّ، حَدَّثَنَا عُبَيْدُ اللَّهِ، أَنْبَأَنَا شَيْبَانُ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، حَدَّثَنِي أَبُو قِلاَبَةَ، أَنَّ أَبَا أَسْمَاءَ، حَدَّثَهُ عَنْ ثَوْبَانَ، قَالَ: سَمِعْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ يَقُولُ: ‏ "‏ أَفْطَرَ الْحَاجِمُ وَالْمَحْجُومُ ‏"‏ ‏.‏\hadithno{1680}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Thawban said:“I heard the Prophet (ﷺ) say: ‘The cupper and the one for whom cupping is done both break their fast.’”}}
\hadithdefcmd{ibnmajah}{1681}{حَدَّثَنَا أَحْمَدُ بْنُ يُوسُفَ السُّلَمِيُّ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ، قَالَ أَنْبَأَنَا شَيْبَانُ، عَنْ يَحْيَى، عَنْ أَبِي قِلاَبَةَ، أَنَّهُ أَخْبَرَهُ أَنَّ شَدَّادَ بْنَ أَوْسٍ بَيْنَمَا هُوَ يَمْشِي مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ بِالْبَقِيعِ. فَمَرَّ عَلَى رَجُلٍ يَحْتَجِمُ بَعْدَ مَا مَضَى مِنَ الشَّهْرِ ثَمَانِي عَشْرَةَ لَيْلَةً. فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أَفْطَرَ الْحَاجِمُ وَالْمَحْجُومُ ‏"‏ ‏.‏\hadithno{1681}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Qilabah that when Shaddad bin Aws was walking with the Messenger of Allah (ﷺ) in Al-Baqi’, he passed by a man who was being cupped, after eighteen days of the month (of Ramadan) had passed. The Messenger of Allah (ﷺ) said:“The cupper and the one for whom cupping is done both break their fast.”}}
\hadithdefcmd{ibnmajah}{1682}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ يَزِيدَ بْنِ أَبِي زِيَادٍ، عَنْ مِقْسَمٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ: احْتَجَمَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَهُوَ صَائِمٌ مُحْرِمٌ ‏.‏\hadithno{1682}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn ‘Abbas said:“The Messenger of Allah (ﷺ) said: “The Messenger of Allah (ﷺ) had cupping done when he was fasting and in Ihram.”}}
\hadithdefcmd{ibnmajah}{1683}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَبْدُ اللَّهِ بْنُ الْجَرَّاحِ، قَالاَ: حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ زِيَادِ بْنِ عِلاَقَةَ، عَنْ عَمْرِو بْنِ مَيْمُونٍ، عَنْ عَائِشَةَ، قَالَتْ: كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ يُقَبِّلُ فِي شَهْرِ الصَّوْمِ ‏.‏\hadithno{1683}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that ‘Aishah said:“The Prophet (ﷺ) used to kiss during the month of fasting.”}}
\hadithdefcmd{ibnmajah}{1684}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ عُبَيْدِ اللَّهِ، عَنِ الْقَاسِمِ، عَنْ عَائِشَةَ، قَالَتْ: كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يُقَبِّلُ وَهُوَ صَائِمٌ. وَأَيُّكُمْ يَمْلِكُ إِرْبَهُ كَمَا كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَمْلِكُ إِرْبَهُ؟\hadithno{1684}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that ‘Aishah said:“The Messenger of Allah (ﷺ) used to kiss when he was fasting, and who among you can control his desire as the Messenger of Allah (ﷺ) used to control his desire?”}}
\hadithdefcmd{ibnmajah}{1685}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ مُسْلِمٍ، عَنْ شُتَيْرِ بْنِ شَكَلٍ، عَنْ حَفْصَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ يُقَبِّلُ وَهُوَ صَائِمٌ ‏.‏\hadithno{1685}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Hafsah that:The Messenger of Allah (ﷺ) used to kiss when he was fasting}}
\hadithdefcmd{ibnmajah}{1686}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا الْفَضْلُ بْنُ دُكَيْنٍ، عَنْ إِسْرَائِيلَ، عَنْ زَيْدِ بْنِ جُبَيْرٍ، عَنْ أَبِي يَزِيدَ الضِّنِّيِّ، عَنْ مَيْمُونَةَ، مَوْلاَةِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَتْ: سُئِلَ النَّبِيُّ ـ صلى الله عليه وسلم ـ عَنْ رَجُلٍ قَبَّلَ امْرَأَتَهُ وَهُمَا صَائِمَانِ قَالَ: ‏ "‏ قَدْ أَفْطَرَا ‏"‏ ‏.‏\hadithno{1686}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Maimunah the freed (female) slave of the Messenger of Allah (ﷺ), said:“The Prophet (ﷺ) was asked about a man who kissed his wife when they were both fasting. He said: ‘They have broken their fast.’”}}
\hadithdefcmd{ibnmajah}{1687}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنِ ابْنِ عَوْنٍ، عَنْ إِبْرَاهِيمَ، قَالَ دَخَلَ الأَسْوَدُ وَمَسْرُوقٌ عَلَى عَائِشَةَ فَقَالاَ أَكَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يُبَاشِرُ وَهُوَ صَائِمٌ قَالَتْ كَانَ يَفْعَلُ وَكَانَ أَمْلَكَكُمْ لإِرْبِهِ ‏.‏\hadithno{1687}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibrahim said:“Al-Aswad and Masruq entered upon ‘Aishah and said: ‘Did the Messenger of Allah (ﷺ) touch (his wife) when he was fasting?’ She said: ‘He used to do that, and he was the strongest of all of you in controlling his desire.’”}}
\hadithdefcmd{ibnmajah}{1688}{حَدَّثَنَا مُحَمَّدُ بْنُ خَالِدِ بْنِ عَبْدِ اللَّهِ الْوَاسِطِيُّ، حَدَّثَنَا أَبِي، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ: رُخِّصَ لِلْكَبِيرِ الصَّائِمِ فِي الْمُبَاشَرَةِ وَكُرِهَ لِلشَّابِّ ‏.‏\hadithno{1688}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn ‘Abbas said:“A concession was granted to those who are older with regard to touching while fasting, but it was disliked on the part of those who are younger.”}}
\hadithdefcmd{ibnmajah}{1689}{حَدَّثَنَا عَمْرُو بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ: قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ لَمْ يَدَعْ قَوْلَ الزُّورِ، وَالْجَهْلَ، وَالْعَمَلَ بِهِ، فَلاَ حَاجَةَ لِلَّهِ فِي أَنْ يَدَعَ طَعَامَهُ وَشَرَابَهُ ‏"‏ ‏.‏\hadithno{1689}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:‘Whoever does not give up evil and ignorant speech, and acting in accordance with that, Allah has no need of his giving up his food and drink.”}}
\hadithdefcmd{ibnmajah}{1690}{حَدَّثَنَا عَمْرُو بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ: قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ رُبَّ صَائِمٍ لَيْسَ لَهُ مِنْ صِيَامِهِ إِلاَّ الْجُوعُ. وَرُبَّ قَائِمٍ لَيْسَ لَهُ مِنْ قِيَامِهِ إِلاَّ السَّهَرُ ‏"‏ ‏.‏\hadithno{1690}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“There are people who fast and get nothing from their fast except hunger, and there are those who pray and get nothing from their prayer but a sleepless night.”}}
\hadithdefcmd{ibnmajah}{1691}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَنْبَأَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ: قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا كَانَ يَوْمُ صَوْمِ أَحَدِكُمْ فَلاَ يَرْفُثْ وَلاَ يَجْهَلْ. فَإِنْ جَهِلَ عَلَيْهِ أَحَدٌ، فَلْيَقُلْ: إِنِّي امْرُؤٌ صَائِمٌ ‏"‏ ‏.‏\hadithno{1691}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“When anyone of you is fasting, let him not utter evil or ignorant speech. If anyone speaks to him in an ignorant manner, let him say: ‘I am fasting.’”}}
\hadithdefcmd{ibnmajah}{1692}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ، أَنْبَأَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ: قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ تَسَحَّرُوا فَإِنَّ فِي السَّحُورِ بَرَكَةً ‏"‏ ‏.‏\hadithno{1692}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Anas bin Malik that the Messenger of Allah (ﷺ) said:“Eat Suhur, for in Suhur there is a blessing.”}}
\hadithdefcmd{ibnmajah}{1693}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو عَامِرٍ، حَدَّثَنَا زَمْعَةُ بْنُ صَالِحٍ، عَنْ سَلَمَةَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ: ‏ "‏ اسْتَعِينُوا بِطَعَامِ السَّحَرِ عَلَى صِيَامِ النَّهَارِ وَبِالْقَيْلُولَةِ عَلَى قِيَامِ اللَّيْلِ ‏"‏ ‏.‏\hadithno{1693}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn ‘Abbas that the Prophet (ﷺ) said:“Seek help by eating Suhur for fasting that day, and by taking a brief rest (at midday) for praying at night.”}}
\hadithdefcmd{ibnmajah}{1694}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ هِشَامٍ الدَّسْتَوَائِيِّ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنْ زَيْدِ بْنِ ثَابِتٍ، قَالَ: تَسَحَّرْنَا مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ثُمَّ قُمْنَا إِلَى الصَّلاَةِ ‏.‏ قُلْتُ كَمْ بَيْنَهُمَا؟ قَالَ: قَدْرُ قِرَاءَةِ خَمْسِينَ آيَةً ‏.‏\hadithno{1694}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Anas bin Malik that Zaid bin Thabit said:“We ate Suhur with the Messenger of Allah (ﷺ) then we got up to perform prayer.” I said: “How long was there between the two?” He said: “As long as it takes to recite fifty verses.”}}
\hadithdefcmd{ibnmajah}{1695}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنْ عَاصِمٍ، عَنْ زِرٍّ، عَنْ حُذَيْفَةَ، قَالَ: تَسَحَّرْتُ مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ هُوَ النَّهَارُ إِلاَّ أَنَّ الشَّمْسَ لَمْ تَطْلُعْ ‏.[ قالَ ابُو إسحاق: حديث حُذَيْفَةَ مَنْسوخٌ لَيْسَ بشَيْء.]‏\hadithno{1695}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Hudhaifah said:“I ate Suhur with the Messenger of Allah (ﷺ) when it was daybreak but the sun had not yet risen.” [(One of the narrators) Abu Ishaq said: “The Hadith of Hudhaifah is abrogated and does not mean anything.”}}
\hadithdefcmd{ibnmajah}{1696}{حَدَّثَنَا يَحْيَى بْنُ حَكِيمٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، وَابْنُ أَبِي عَدِيٍّ، عَنْ سُلَيْمَانَ التَّيْمِيِّ، عَنْ أَبِي عُثْمَانَ النَّهْدِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ: ‏ "‏ لاَ يَمْنَعَنَّ أَحَدَكُمْ أَذَانُ بِلاَلٍ مِنْ سُحُورِهِ. فَإِنَّهُ يُؤَذِّنُ لِيَنْتَبِهَ نَائِمُكُمْ، وَلِيَرْجِعَ قَائِمُكُمْ. وَلَيْسَ الْفَجْرُ أَنْ يَقُولَ هَكَذَا. وَلَكِنْ هَكَذَا، يَعْتَرِضُ فِي أُفُقِ السَّمَاءِ ‏"‏ ‏.‏\hadithno{1696}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from ‘Abdullah bin Mas’ud that the Messenger of Allah (ﷺ) said:“The Adhan of Bilal should not prevent anyone of you from eating Suhur, for he gives the Adhan to alert those among you who are asleep, and so that anyone who is praying can prepare himself for fasting. The Fajr does not come in this manner, rather it comes in this manner, and it appears along the horizon.”}}
\hadithdefcmd{ibnmajah}{1697}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، وَمُحَمَّدُ بْنُ الصَّبَّاحِ، قَالاَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، عَنْ أَبِيهِ، عَنْ سَهْلِ بْنِ سَعْدٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ: ‏ "‏ لاَ يَزَالُ النَّاسُ بِخَيْرٍ مَا عَجَّلُوا الْإِفْطارَ ‏"‏ ‏.‏\hadithno{1697}\hadithgrade{Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Sahl bin Sa’d that the Prophet (ﷺ) said:“The people will remain upon goodness as long as they hasten to break their fast.”}}
\hadithdefcmd{ibnmajah}{1698}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ: قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ يَزَالُ النَّاسُ بِخَيْرٍ مَا عَجَّلُوا الْفِطْرَ. عَجِّلُوا الْفِطْرَ، فَإِنَّ الْيَهُودَ يُؤَخِّرُونَ ‏"‏ ‏.‏\hadithno{1698}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:"The people will remain upon goodness so long as they hasten to break the fast. Hasten to break the fast, for the Jews delay it}}
\hadithdefcmd{ibnmajah}{1699}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الرَّحِيمِ بْنُ سُلَيْمَانَ، وَمُحَمَّدُ بْنُ فُضَيْلٍ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ عَاصِمٍ الأَحْوَلِ، عَنْ حَفْصَةَ بِنْتِ سِيرِينَ، عَنِ الرَّبَابِ أُمِّ الرَّائِحِ بِنْتِ صُلَيْعٍ، عَنْ عَمِّهَا، سَلْمَانَ بْنِ عَامِرٍ قَالَ: قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا أَفْطَرَ أَحَدُكُمْ، فَلْيُفْطِرْ عَلَى تَمْرَةٍ. فَإِنْ لَمْ يَجِدْ، فَلْيُفْطِرْ عَلَى الْمَاءِ. فَإِنَّهُ طَهُورٌ ‏"‏ ‏.‏\hadithno{1699}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Salman bin ‘Amr narrated that the Messenger of Allah (ﷺ) said:"When any one of you breaks his fast, let him break it with dates. If he cannot find dates, then let him break it with water, for it is a means of purification}}
\hadithdefcmd{ibnmajah}{1700}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ الْقَطَوَانِيُّ، عَنْ إِسْحَاقَ بْنِ حَازِمٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرِ بْنِ عَمْرِو بْنِ حَزْمٍ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، عَنْ حَفْصَةَ، قَالَتْ: قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ صِيَامَ لِمَنْ لَمْ يَفْرِضْهُ مِنَ اللَّيْلِ ‏"‏ ‏.‏\hadithno{1700}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Hafsah that the Messenger of Allah (ﷺ) said:"There is no fast for the one who did not make it incumbent upon himself from the night before}}
\hadithdefcmd{ibnmajah}{1701}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ مُوسَى، حَدَّثَنَا شَرِيكٌ، عَنْ طَلْحَةَ بْنِ يَحْيَى، عَنْ مُجَاهِدٍ، عَنْ عَائِشَةَ، قَالَتْ دَخَلَ عَلَىَّ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ: ‏"‏ هَلْ عِنْدَكُمْ شَىْءٌ؟ ‏"‏ ‏.‏ فَنَقُولُ: لاَ ‏.‏ فَيَقُولُ: ‏"‏ إِنِّي صَائِمٌ ‏"‏ ‏.‏ فَيُقِيمُ عَلَى صَوْمِهِ ثُمَّ يُهْدَى لَنَا شَىْءٌ فَيُفْطِرُ ‏.‏ قَالَتْ: وَرُبَّمَا صَامَ وَأَفْطَرَ ‏.‏ قُلْتُ: كَيْفَ ذَا؟ قَالَتْ: إِنَّمَا مَثَلُ هَذَا مَثَلُ الَّذِي يَخْرُجُ بِصَدَقَةٍ فَيُعْطِي بَعْضَهَا وَيُمْسِكُ بَعْضًا ‏.‏\hadithno{1701}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that ‘Aishah said:“The Messenger of Allah (ﷺ) would enter upon me and say: ‘Do you have anything (any food)?’ If we said: ‘No,’ he would say: ‘Then I am fasting.’ So he would continue fasting, then it we were given some food, he would break his fast.” She said: “Sometimes he would fast and (then) break fast (i.e., combine fasting and breaking fast in one day).” I said: “How is that?” She said: “Like the one who goes out with charity (i.e., something to give in charity),and he gives some away and keeps some.”}}
\hadithdefcmd{ibnmajah}{1702}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ الصَّبَّاحِ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ يَحْيَى بْنِ جَعْدَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو الْقَارِيِّ، قَالَ: سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ لاَ وَرَبِّ الْكَعْبَةِ مَا أَنَا قُلْتُ: ‏ "‏ مَنْ أَصْبَحَ وَهُوَ جُنُبٌ فَلْيُفْطِرْ ‏"‏ ‏.‏ مُحَمَّدٌ ـ صلى الله عليه وسلم ـ قَالَهُ ‏.‏\hadithno{1702}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that ‘Abdullah bin ‘Amr Al-Qari said:“I heard Abu hurairah say: ‘No, by the Lord of the Ka’bah! I did not say: “Whoever wakes up in a state of sexual impurity (and wants to fast) then he must not fast.” Muhammad (ﷺ) said it.’”}}
\hadithdefcmd{ibnmajah}{1703}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ مُطَرِّفٍ، عَنِ الشَّعْبِيِّ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ: كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ يَبِيتُ جُنُبًا. فَيَأْتِيهِ بِلاَلٌ، فَيُؤْذِنُهُ بِالصَّلاَةِ فَيَقُومُ فَيَغْتَسِلُ. فَأَنْظُرُ إِلَى تَحَدُّرِ الْمَاءِ مِنْ رَأْسِهِ. ثُمَّ يَخْرُجُ فَأَسْمَعُ صَوْتَهُ فِي صَلاَةِ الْفَجْرِ ‏.‏ قَالَ مُطَرِّفٌ: فَقُلْتُ لِعامِرٍأفِي رَمَضَانَ؟ قَالَ رَمَضَانُ وَغَيْرُهُ سَوَاءٌ ‏.‏\hadithno{1703}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that ‘Aishah said:“The Prophet (ﷺ) used to spend the night in a state of sexual impurity, then Bilal would come to him and inform him that it is time for prayer. So he would get up and have a bath, and I would see the water dripping from his head, then he would go out and I would hear his voice during Fajr prayer.” (One of the narrators) Mutarrif said: "I said to Amir: 'Was that during Ramadan?' He said: 'In Ramadan and at other times}}
\hadithdefcmd{ibnmajah}{1704}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، قَالَ سَأَلْتُ أُمَّ سَلَمَةَ عَنِ الرَّجُلِ، يُصْبِحُ، وَهُوَ جُنُبٌ، يُرِيدُ الصَّوْمَ؟ قَالَتْ: كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يُصْبِحُ جُنُبًا مِنَ الْوِقَاعِ، لاَ مِنِ احْتِلاَمٍ، ثُمَّ يَغْتَسِلُ وَيُتِمُّ صَوْمَهُ ‏.‏\hadithno{1704}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Nafi’ said:“I asked Umm Salamah about a man who gets up in the morning when he is in a state of sexual impurity and wants to fast. She said: “The Messenger of Allah (ﷺ) used to get up in the morning in a state of sexual impurity after having intercourse, not from a wet dream, then he would take a bath and complete his fast.’”}}
\hadithdefcmd{ibnmajah}{1705}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عُبَيْدُ بْنُ سَعِيدٍ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، وَأَبُو دَاوُدَ قَالُوا حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ مُطَرِّفِ بْنِ عَبْدِ اللَّهِ بْنِ الشِّخِّيرِ، عَنْ أَبِيهِ، قَالَ: قَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ صَامَ الأَبَدَ، فَلاَ صَامَ وَلاَ أَفْطَرَ ‏"‏ ‏.‏\hadithno{1705}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from ‘Abdullah bin Shikhkhir that his father said:“The Prophet (ﷺ) said: ‘Whoever fasts continually, he neither fasts nor breaks his fast.’”}}
\hadithdefcmd{ibnmajah}{1706}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ مِسْعَرٍ، وَسُفْيَانَ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ أَبِي الْعَبَّاسِ الْمَكِّيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ: قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ صَامَ مَنْ صَامَ الأَبَدَ ‏"‏ ‏.‏\hadithno{1706}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from ‘Abdullah bin ‘Amr that the Messenger of Allah (ﷺ) said:“There is no fasting for one who fasts continually.”}}
\hadithdefcmd{ibnmajah}{1707}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا شُعْبَةُ، عَنْ أَنَسِ بْنِ سِيرِينَ، عَنْ عَبْدِ الْمَلِكِ بْنِ الْمِنْهَالِ، عَنْ أَبِيهِ، عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ أَنَّهُ كَانَ يَأْمُرُ بِصِيَامِ الْبِيضِ ثَلاَثَ عَشْرَةَ وَأَرْبَعَ عَشْرَةَ وَخَمْسَ عَشْرَةَ وَيَقُولُ: ‏ "‏ هُوَ كَصَوْمِ الدَّهْرِ أَوْ كَهَيْئَةِ صَوْمِ الدَّهْرِ ‏"‏ ‏.‏ حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَنْبَأَنَا حَبَّانُ بْنُ هِلاَلٍ، حَدَّثَنَا هَمَّامٌ، عَنْ أَنَسِ بْنِ سِيرِينَ، حَدَّثَنِي عَبْدُ الْمَلِكِ بْنُ قَتَادَةَ بْنِ مِلْحَانَ الْقَيْسِيُّ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ نَحْوَهُ ‏.‏ قَالَ: ابْنُ مَاجَهْ أَخْطَأَ شُعْبَةُ وَأَصَابَ هَمَّامٌ ‏.‏\hadithno{1707}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Abdul-Malik bin Minhal, from his father that:The Messenger of Allah (ﷺ) used to enjoin fasting the bright days – the thirteenth, fourteenth and fifteenth (when the moon is full). He said: “It is like fasting for a lifetime.” Another chain from 'Abdul-Malik bin Qatadah bin Malhan Al-Qaisi, from his father, from the Prophet (ﷺ) with similar wording. Ibn Majah said: Shu'bah erred (in the name of one of the narrators)and Hammam was correct}}
\hadithdefcmd{ibnmajah}{1708}{حَدَّثَنَا سَهْلُ بْنُ أَبِي سَهْلٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ عَاصِمٍ الأَحْوَلِ، عَنْ أَبِي عُثْمَانَ، عَنْ أَبِي ذَرٍّ، قَالَ: قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ مَنْ صَامَ ثَلاَثَةَ أَيَّامٍ مِنْ كُلِّ شَهْرٍ فَذَلِكَ صَوْمُ الدَّهْرِ ‏"‏ ‏.‏ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ تَصْدِيقَ ذَلِكَ فِي كِتَابِهِ ‏\{مَنْ جَاءَ بِالْحَسَنَةِ فَلَهُ عَشْرُ أَمْثَالِهَا\}‏ فَالْيَوْمُ بِعَشْرَةِ أَيَّامٍ ‏.‏\hadithno{1708}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Dharr that the Messenger of Allah (ﷺ) said:“Whoever fasts three days in every month, that is fasting for a lifetime.” Then, in testimony of that, Allah revealed: “Whoever brings a good deed shall have ten time the like thereof to his credit.” [6:160] So one day is equivalent to ten (in reward)}}
\hadithdefcmd{ibnmajah}{1709}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا غُنْدَرٌ، عَنْ شُعْبَةَ، عَنْ يَزِيدَ الرِّشْكِ، عَنْ مُعَاذَةَ الْعَدَوِيَّةِ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ: كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَصُومُ ثَلاَثَةَ أَيَّامٍ مِنْ كُلِّ شَهْرٍ ‏.‏ قُلْتُ مِنْ أَيِّهِ؟ قَالَتْ: لَمْ يَكُنْ يُبَالِي مِنْ أَيِّهِ كَانَ ‏.‏\hadithno{1709}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Mu’adhah Al-‘Adawiyyah that ‘Aishah said:“The Messenger of Allah (ﷺ) used to fast three days of each month.” I said: “Which were they?” She said: “He did not care which days they were.”}}
\hadithdefcmd{ibnmajah}{1710}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ ابْنِ أَبِي لَبِيدٍ، عَنْ أَبِي سَلَمَةَ، قَالَ: سَأَلْتُ عَائِشَةَ عَنْ صِيَامِ النَّبِيِّ، ـ صلى الله عليه وسلم ـ فَقَالَتْ: كَانَ يَصُومُ حَتَّى نَقُولَ قَدْ صَامَ ‏.‏ وَيُفْطِرُ حَتَّى نَقُولَ: قَدْ أَفْطَرَ. وَلَمْ أَرَهُ صَامَ مِنْ شَهْرٍ قَطُّ أَكْثَرَ مِنْ صِيَامِهِ مِنْ شَعْبَانَ. كَانَ يَصُومُ شَعْبَانَ كُلَّهُ. كَانَ يَصُومُ شَعْبَانَ إِلاَّ قَلِيلاً ‏.‏\hadithno{1710}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Salamah said:“I asked ‘Aishah about the fasting of the Prophet (ﷺ). She said: ‘He used to fast until we thought he would always fast. And he used to not fast until we thought he would always not fast. I never saw him fast more in any month than in Sha’ban. He used to fast all of Sha’ban; he used to fast all of Sha’ban except a little.’”}}
\hadithdefcmd{ibnmajah}{1711}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ: كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَصُومُ حَتَّى نَقُولَ: لاَ يُفْطِرُ. وَيُفْطِرُ حَتَّى نَقُولَ: لاَ يَصُومُ ‏.‏ وَمَا صَامَ شَهْرًا مُتَتَابِعًا إِلاَّ رَمَضَانَ، مُنْذُ قَدِمَ الْمَدِينَةَ ‏.‏\hadithno{1711}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Ibn ‘Abbas said:“The Messenger of Allah (ﷺ) used to fast until we thought he would never stop fasting. And he used to not fast until we thought we would never fast. And he never fasted any complete month apart from Ramadan, from the time he came to Al- Madinah.”}}
\hadithdefcmd{ibnmajah}{1712}{حَدَّثَنَا أَبُو إِسْحَاقَ الشَّافِعِيُّ، إِبْرَاهِيمُ بْنُ مُحَمَّدِ بْنِ الْعَبَّاسِ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، قَالَ: سَمِعْتُ عَمْرَو بْنَ أَوْسٍ قَالَ: سَمِعْتُ عَبْدَ اللَّهِ بْنَ عَمْرٍو يَقُولُ: قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أَحَبُّ الصِّيَامِ إِلَى اللَّهِ صِيَامُ دَاوُدَ. كَانَ يَصُومُ يَوْمًا وَيُفْطِرُ يَوْمًا. وَأَحَبُّ الصَّلاَةِ إِلَى اللَّهِ صَلاَةُ دَاوُدَ. كَانَ يَنَامُ نِصْفَ اللَّيْلِ وَيُصَلِّي ثُلُثَهُ وَيَنَامُ سُدُسَهُ ‏"‏ ‏.‏\hadithno{1712}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from ‘Abdullah bin ‘Amr that the Messenger of Allah (ﷺ) said:“The most beloved fast to Allah is the fast of Dawud, for he used to fast one day and not the next. And the most beloved of prayer to Allah is the prayer of Dawud; he used to sleep half of the night, pray one-third of the night and sleep one-sixth of the night.”}}
\hadithdefcmd{ibnmajah}{1713}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، حَدَّثَنَا غَيْلاَنُ بْنُ جَرِيرٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَعْبَدٍ الزِّمَّانِيِّ، عَنْ أَبِي قَتَادَةَ، قَالَ: قَالَ عُمَرُ بْنُ الْخَطَّابِ: يَا رَسُولَ اللَّهِ! كَيْفَ بِمَنْ يَصُومُ يَوْمَيْنِ وَيُفْطِرُ يَوْمًا؟ قَالَ: ‏"‏ وَيُطِيقُ ذَلِكَ أَحَدٌ ‏"‏ ‏.‏ قَالَ: يَا رَسُولَ اللَّهِ! كَيْفَ بِمَنْ يَصُومُ يَوْمًا وَيُفْطِرُ يَوْمًا؟ قَالَ: ‏"‏ ذَلِكَ صَوْمُ دَاوُدَ ‏"‏ ‏.‏ قَالَ: كَيْفَ بِمَنْ يَصُومُ يَوْمًا وَيُفْطِرُ يَوْمَيْنِ؟ قَالَ: ‏"‏ وَدِدْتُ أَنِّي طُوِّقْتُ ذَلِكَ ‏"‏ ‏.‏\hadithno{1713}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Qatadah said:“Umar bin Khattab said: ‘O Messenger of Allah! What about a person who fasts two days and does not fast one day?’ He said: ‘Is anyone able to do that?’ He said: ‘O Messenger of Allah! What about a person who fasts one day and not the next?’ He said: ‘That is the fast of Dawud.’ He said: ‘What about a man who fasts one day and does not fast the next two days?’ He said: ‘I wish that I were given the ability to do that.’”}}
\hadithdefcmd{ibnmajah}{1714}{حَدَّثَنَا سَهْلُ بْنُ أَبِي سَهْلٍ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي مَرْيَمَ، عَنِ ابْنِ لَهِيعَةَ، عَنْ جَعْفَرِ بْنِ رَبِيعَةَ، عَنْ أَبِي فِرَاسٍ، أَنَّهُ سَمِعَ عَبْدَ اللَّهِ بْنَ عَمْرٍو يَقُولُ: سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ: ‏ "‏ صَامَ نُوحٌ الدَّهْرَ إِلاَّ يَوْمَ الْفِطْرِ وَيَوْمَ الأَضْحَى ‏"‏ ‏.‏\hadithno{1714}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Firas that he heard ‘Abdullah bin ‘Amr say:“I heard the Messenger of Allah (ﷺ) say: ‘(Prophet) Nuh fasted for a lifetime, except for the Day of Fitr and the Day of Adha.’”}}
\hadithdefcmd{ibnmajah}{1715}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا بَقِيَّةُ، حَدَّثَنَا صَدَقَةُ بْنُ خَالِدٍ، حَدَّثَنَا يَحْيَى بْنُ الْحَارِثِ الذِّمَارِيُّ، قَالَ سَمِعْتُ أَبَا أَسْمَاءَ الرَّحَبِيَّ، عَنْ ثَوْبَانَ، مَوْلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ أَنَّهُ قَالَ: ‏"‏ مَنْ صَامَ سِتَّةَ أَيَّامٍ بَعْدَ الْفِطْرِ كَانَ تَمَامَ السَّنَةِ ‏\{مَنْ جَاءَ بِالْحَسَنَةِ فَلَهُ عَشْرُ أَمْثَالِهَا\}‏ ‏"‏ ‏.‏\hadithno{1715}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Thawban, the freed slave of the Messenger of Allah (ﷺ), that the Messenger of Allah (ﷺ) said:“Whoever fasts six days after the Fitr will have completed the year, for whoever does a good deed will have the reward of ten like it.”}}
\hadithdefcmd{ibnmajah}{1716}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ سَعْدِ بْنِ سَعِيدٍ، عَنْ عُمَرَ بْنِ ثَابِتٍ، عَنْ أَبِي أَيُّوبَ، قَالَ: قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ صَامَ رَمَضَانَ ثُمَّ أَتْبَعَهُ بِسِتٍّ مِنْ شَوَّالٍ، كَانَ كَصَوْمِ الدَّهْرِ ‏"‏ ‏.‏\hadithno{1716}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Ayyub that the Messenger of Allah (ﷺ) said:“Whoever fasts Ramadan then follows it with six days of Shawwal, it is as if he fasted for a lifetime.”}}
\hadithdefcmd{ibnmajah}{1717}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحِ بْنِ الْمُهَاجِرِ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنِ ابْنِ الْهَادِ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنِ النُّعْمَانِ بْنِ أَبِي عَيَّاشٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ: قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ صَامَ يَوْمًا فِي سَبِيلِ اللَّهِ، بَاعَدَ اللَّهُ، بِذَلِكَ الْيَوْمِ، النَّارَ عَنْ وَجْهِهِ سَبْعِينَ خَرِيفًا ‏"‏ ‏.‏\hadithno{1717}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Abu Sa’eed Al-Khudri that the Messenger of Allah (ﷺ) said:“Whoever fasts one day in the cause of Allah, Allah will keep the Fire away from his face the distance of seventy autumns (years) for that day.”}}
\hadithdefcmd{ibnmajah}{1718}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا أَنَسُ بْنُ عِيَاضٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الْعَزِيزِ اللَّيْثِيُّ، عَنِ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ: قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ صَامَ يَوْمًا فِي سَبِيلِ اللَّهِ، زَحْزَحَ اللَّهُ وَجْهَهُ عَنِ النَّارِ سَبْعِينَ خَرِيفًا ‏"‏ ‏.‏\hadithno{1718}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“Whoever fasts one day for the sake of Allah, Allah will move his face away from the Fire a distance of seventy autumns (years).”}}
\hadithdefcmd{ibnmajah}{1719}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الرَّحِيمِ بْنُ سُلَيْمَانَ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ: قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أَيَّامُ مِنًى، أَيَّامُ أَكْلٍ وَشُرْبٍ ‏"‏ ‏.‏\hadithno{1719}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“The days of Mina (11th, 12th, and 13th of Dhul-Hijjah) are days of eating and drinking.’”}}
\hadithdefcmd{ibnmajah}{1720}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ نَافِعِ بْنِ جُبَيْرِ بْنِ مُطْعِمٍ، عَنْ بِشْرِ بْنِ سُحَيْمٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ خَطَبَ أَيَّامَ التَّشْرِيقِ فَقَالَ: ‏ "‏ لاَ يَدْخُلُ الْجَنَّةَ إِلاَّ نَفْسٌ مُسْلِمَةٌ. وَإِنَّ هَذِهِ الأَيَّامَ أَيَّامُ أَكْلٍ وَشُرْبٍ ‏"‏ ‏.‏\hadithno{1720}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Bishr bin Suhaim that:The Messenger of Allah (ﷺ) delivered a sermon on the days of Tashriq (11th, 12th, and 13th of Dhul-Hijjah) and said: “No one will enter Paradise but a Muslim soul, and these days are the days of eating and drinking.”}}
\hadithdefcmd{ibnmajah}{1721}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ يَعْلَى التَّيْمِيُّ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ قَزَعَةَ، عَنْ أَبِي سَعِيدٍ، عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ أَنَّهُ نَهَى عَنْ صَوْمِ يَوْمِ الْفِطْرِ وَيَوْمِ الأَضْحَى ‏.‏\hadithno{1721}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Abu Sa’eed that:The Messenger of Allah (ﷺ) forbade fasting on the Day of Fitr and the Day of Adha}}
\hadithdefcmd{ibnmajah}{1722}{حَدَّثَنَا سَهْلُ بْنُ أَبِي سَهْلٍ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي عُبَيْدٍ، قَالَ شَهِدْتُ الْعِيدَ مَعَ عُمَرَ بْنِ الْخَطَّابِ فَبَدَأَ بِالصَّلاَةِ قَبْلَ الْخُطْبَةِ فَقَالَ: إِنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ نَهَى عَنْ صِيَامِ هَذَيْنِ الْيَوْمَيْنِ، يَوْمِ الْفِطْرِ وَيَوْمِ الأَضْحَى. أَمَّا يَوْمُ الْفِطْرِ، فَيَوْمُ فِطْرِكُمْ مِنْ صِيَامِكُمْ. وَيَوْمُ الأَضْحَى تَأْكُلُونَ فِيهِ مِنْ لَحْمِ نُسُكِكُمْ ‏.‏\hadithno{1722}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Abu ‘Ubaid said:“I was present for ‘Eid with ‘Umar bin Khattab. He started with the prayer before the sermon, and said: ‘The Messenger of Allah (ﷺ) forbade fasting on these two days, the Day of Fitr and the Day of Adha. As for the Day of Fitr, it is the day when you break your fast, and on the Day of Adha you eat the meat of your sacrifices.’”}}
\hadithdefcmd{ibnmajah}{1723}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، وَحَفْصُ بْنُ غِيَاثٍ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ: نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنْ صَوْمِ يَوْمِ الْجُمُعَةِ إِلاَّ بِيَوْمٍ قَبْلَهُ، أَوْ يَوْمٍ بَعْدَهُ ‏.‏\hadithno{1723}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Abu Hurairah said:“The Messenger of Allah (ﷺ) forbade fasting on a Friday unless it (is joined to) the day before or the day after.”}}
\hadithdefcmd{ibnmajah}{1724}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَبْدِ الْحَمِيدِ بْنِ جُبَيْرِ بْنِ شَيْبَةَ، عَنْ مُحَمَّدِ بْنِ عَبَّادِ بْنِ جَعْفَرٍ، قَالَ: سَأَلْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ وَأَنَا أَطُوفُ، بِالْبَيْتِ: أَنَهَى النَّبِيُّ ـ صلى الله عليه وسلم ـ عَنْ صِيَامِ يَوْمِ الْجُمُعَةِ؟ قَالَ: نَعَمْ وَرَبِّ هَذَا الْبَيْتِ ‏.‏\hadithno{1724}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Muhammad bin ‘Abbad bin Ja’far said:“While I was circumambulating the House, I asked Jabir bin ‘Abdullah: ‘Did the Prophet (ﷺ) forbid fasting on a Friday?’ He said: ‘Yes, by the Lord of this House.’”}}
\hadithdefcmd{ibnmajah}{1725}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَنْبَأَنَا أَبُو دَاوُدَ، حَدَّثَنَا شَيْبَانُ، عَنْ عَاصِمٍ، عَنْ زِرٍّ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ: قَلَّمَا رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يُفْطِرُ يَوْمَ الْجُمُعَةِ ‏.‏\hadithno{1725}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that ‘Abdullah bin Mas’ud said:“I rarely saw the Messenger of Allah (ﷺ) not fasting on a Friday.”}}
\hadithdefcmd{ibnmajah}{1726}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، عَنْ ثَوْرِ بْنِ يَزِيدَ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنْ عَبْدِ اللَّهِ بْنِ بُسْرٍ، قَالَ: قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ تَصُومُوا يَوْمَ السَّبْتِ إِلاَّ فِيمَا افْتُرِضَ عَلَيْكُمْ. فَإِنْ لَمْ يَجِدْ أَحَدُكُمْ إِلاَّ عُودَ عِنَبٍ، أَوْ لِحَاءَ شَجَرَةٍ، فَلْيَمُصَّهُ ‏"‏ ‏.‏ حَدَّثَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، حَدَّثَنَا سُفْيَانُ بْنُ حَبِيبٍ، عَنْ ثَوْرِ بْنِ يَزِيدَ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنْ عَبْدِ اللَّهِ بْنِ بُسْرٍ، عَنْ أُخْتِهِ، قَالَتْ: قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَذَكَرَ نَحْوَهُ ‏.‏\hadithno{1726}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from ‘Abdullah bin Busr that the Messenger of Allah (ﷺ) said:“Do not fast on Saturdays apart from days when you are obliged to fast. If anyone of you cannot find anything other than grape stalks or the bark of a tree, let him suck on it.” Another chain from 'Abdullah bin Busr, from his sister who said: "The Messenger of Allah (ﷺ) said," and he mentioned similarly}}
\hadithdefcmd{ibnmajah}{1727}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ مُسْلِمٍ الْبَطِينِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ: قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ مَا مِنْ أَيَّامٍ الْعَمَلُ الصَّالِحُ فِيهَا أَحَبُّ إِلَى اللَّهِ مِنْ هَذِهِ الأَيَّامِ ‏"‏ ‏.‏ يَعْنِي الْعَشْرَ ‏.‏ قَالُوا: يَا رَسُولَ اللَّهِ! وَلاَ الْجِهَادُ فِي سَبِيلِ اللَّهِ قَالَ: ‏"‏ وَلاَ الْجِهَادُ فِي سَبِيلِ اللَّهِ. إِلاَّ رَجُلٌ خَرَجَ بِنَفْسِهِ وَمَالِهِ فَلَمْ يَرْجِعْ مِنْ ذَلِكَ بِشَىْءٍ ‏"‏ ‏.‏\hadithno{1727}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Ibn ‘Abbas that the Messenger of Allah (ﷺ) said:“There are no days during which righteous deeds are more beloved to Allah than these days,” meaning the (first) ten days of Dhul- Hijjah. They said: “O Messenger of Allah! Not even Jihad in the cause of Allah?” He said: “Not even Jihad in the cause of Allah, unless a man goes out with himself and his wealth and does not bring anything back.”}}
\hadithdefcmd{ibnmajah}{1728}{حَدَّثَنَا عُمَرُ بْنُ شَبَّةَ بْنِ عَبِيدَةَ، حَدَّثَنَا مَسْعُودُ بْنُ وَاصِلٍ، عَنِ النَّهَّاسِ بْنِ قَهْمٍ، عَنْ قَتَادَةَ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ: قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَا مِنْ أَيَّامِ الدُّنْيَا أَيَّامٌ، أَحَبُّ إِلَى اللَّهِ سُبْحَانَهُ أَنْ يُتَعَبَّدَ لَهُ فِيهَا، مِنْ أَيَّامِ الْعَشْرِ. وَإِنَّ صِيَامَ يَوْمٍ فِيهَا لَيَعْدِلُ صِيَامَ سَنَةٍ، وَلَيْلَةٍ فِيهَا بِلَيْلَةِ الْقَدْرِ ‏"‏ ‏.‏\hadithno{1728}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“There are no days in this world during which worship is more beloved to Allah, Glorious is He, than the (first) ten days (of Dhul- Hijjah). Fasting one of these days is equivalent to fasting for one year, and one night of them is equal to Lailatul-Qadr.”}}
\hadithdefcmd{ibnmajah}{1729}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ: مَا رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ صَامَ الْعَشْرَ قَطُّ ‏.‏\hadithno{1729}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Aswad that ‘Aishah said:“I never saw the Messenger of Allah (ﷺ) fasting the (first) ten days (of Dhul- Hijjah).”}}
\hadithdefcmd{ibnmajah}{1730}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ، أَنْبَأَنَا حَمَّادُ بْنُ زَيْدٍ، حَدَّثَنَا غَيْلاَنُ بْنُ جَرِيرٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَعْبَدٍ الزِّمَّانِيِّ، عَنْ أَبِي قَتَادَةَ، قَالَ: قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ صِيَامُ يَوْمِ عَرَفَةَ، إِنِّي أَحْتَسِبُ عَلَى اللَّهِ أَنْ يُكَفِّرَ السَّنَةَ الَّتِي قَبْلَهُ وَالَّتِي بَعْدَهُ ‏"‏ ‏.‏\hadithno{1730}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Qatadah that the Messenger of Allah (ﷺ) said:“Fasting on the Day of ‘Arafah, I hope from Allah, expiates for the sins of the year before and the year after.”}}
\hadithdefcmd{ibnmajah}{1731}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا يَحْيَى بْنُ حَمْزَةَ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ، عَنْ عِيَاضِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنْ قَتَادَةَ بْنِ النُّعْمَانِ، قَالَ: سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ: ‏ "‏ مَنْ صَامَ يَوْمَ عَرَفَةَ، غُفِرَ لَهُ سَنَةٌ أَمَامَهُ وَسَنَةٌ بَعْدَهُ ‏"‏ ‏.‏\hadithno{1731}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Qatadah bin Nu’man said:“I heard the Messenger of Allah (ﷺ) say: ‘Whoever fasts the Day of ‘Arafah, his sins of the previous and following year will be forgiven.’”}}
\hadithdefcmd{ibnmajah}{1732}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنِي حَوْشَبُ بْنُ عَقِيلٍ، حَدَّثَنِي مَهْدِيٌّ الْعَبْدِيُّ، عَنْ عِكْرِمَةَ، قَالَ: دَخَلْتُ عَلَى أَبِي هُرَيْرَةَ فِي بَيْتِهِ فَسَأَلْتُهُ عَنْ صَوْمِ يَوْمِ عَرَفَةَ بِعَرَفَاتٍ؟ فَقَالَ: أَبُو هُرَيْرَةَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنْ صَوْمِ يَوْمِ عَرَفَةَ بِعَرَفَاتٍ ‏.‏\hadithno{1732}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that ‘Ikrimah said:“I entered upon Abu Hurairah in his house and asked him about fasting the Day of ‘Arafah at ‘Arafat. Abu Hurairah said: ‘The Messenger of Allah (ﷺ) forbade fasting the Day of ‘Arafah at ‘Arafat.’”}}
\hadithdefcmd{ibnmajah}{1733}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ: كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَصُومُ عَاشُورَاءَ، وَيَأْمُرُ بِصِيَامِهِ ‏.‏\hadithno{1733}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that ‘Aishah said:“The Messenger of Allah (ﷺ) used to fast ‘Ashura’, and he ordered (others) to fast it too.”}}
\hadithdefcmd{ibnmajah}{1734}{حَدَّثَنَا سَهْلُ بْنُ أَبِي سَهْلٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَيُّوبَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ: قَدِمَ النَّبِيُّ ـ صلى الله عليه وسلم ـ الْمَدِينَةَ فَوَجَدَ الْيَهُودَ صُيَّامًا. فَقَالَ: ‏"‏ مَا هَذَا؟ ‏"‏ ‏.‏ قَالُوا: هَذَا يَوْمٌ أَنْجَى اللَّهُ فِيهِ مُوسَى، وَأَغْرَقَ فِيهِ فِرْعَوْنَ، فَصَامَهُ مُوسَى شُكْرًا ‏.‏ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ نَحْنُ أَحَقُّ بِمُوسَى مِنْكُمْ ‏"‏ ‏.‏ فَصَامَهُ، وَأَمَرَ بِصِيَامِهِ ‏.‏\hadithno{1734}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Ibn ‘Abbas said:“The Prophet (ﷺ) came to Al- Madinah, and he found the Jews observing a fast. He said: ‘What is this?’ They said: ‘This is the day when Allah saved Musa and drowned Pharaoh, so Musa fasted this day in gratitude.’ The Messenger of Allah (ﷺ) said: ‘We have more right to Musa than you do.’ So he fasted (that day) and enjoined (others) to fast it also.’”}}
\hadithdefcmd{ibnmajah}{1735}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ حُصَيْنٍ، عَنِ الشَّعْبِيِّ، عَنْ مُحَمَّدِ بْنِ صَيْفِيٍّ، قَالَ: قَالَ لَنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَوْمَ عَاشُورَاءَ: ‏"‏ مِنْكُمْ أَحَدٌ طَعِمَ الْيَوْمَ؟ ‏"‏ ‏.‏ قُلْنَا: مِنَّا طَعِمَ وَمِنَّا مَنْ لَمْ يَطْعَمْ ‏.‏ قَالَ: ‏"‏ فَأَتِمُّوا بَقِيَّةَ يَوْمِكُمْ. مَنْ كَانَ طَعِمَ وَمَنْ لَمْ يَطْعَمْ. فَأَرْسِلُوا إِلَى أَهْلِ الْعَرُوضِ فَلْيُتِمُّوا بَقِيَّةَ يَوْمِهِمْ ‏"‏ ‏.‏ قَالَ يَعْنِي أَهْلَ الْعَرُوضِ حَوْلَ الْمَدِينَةِ ‏.‏\hadithno{1735}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Muhammad bin Saifi that the Messenger of Allah (ﷺ) said to us on the Day of ‘Ashura’:“Has anyone among you eaten today?” We said: “Some of us have eaten and some of us have not.” He said: “Complete the rest of your day (i.e., do not eat for the rest of the day), whoever has eaten and whoever has not eaten. And send word to the people of the suburbs to complete the rest of their day.” He was referring to the people of the suburbs around Al-Madinah}}
\hadithdefcmd{ibnmajah}{1736}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنِ الْقَاسِمِ بْنِ عَبَّاسِ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَيْرٍ، مَوْلَى ابْنِ عَبَّاسٍ عَنِ ابْنِ عَبَّاسٍ، قَالَ: قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لَئِنْ بَقِيتُ إِلَى قَابِلٍ لأَصُومَنَّ الْيَوْمَ التَّاسِعَ ‏"‏ ‏.‏\hadithno{1736}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn ‘Abbas that the Messenger of Allah (ﷺ) said:“If I live until next year, I will fast the ninth day (of Muharram) too.”}}
\hadithdefcmd{ibnmajah}{1737}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ ذُكِرَ عِنْدَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ يَوْمُ عَاشُورَاءَ فَقَالَ: رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ كَانَ يَوْمًا يَصُومُهُ أَهْلُ الْجَاهِلِيَّةِ. فَمَنْ أَحَبَّ مِنْكُمْ أَنْ يَصُومَهُ فَلْيَصُمْهُ، وَمَنْ كَرِهَهُ فَلْيَدَعْهُ ‏"‏ ‏.‏\hadithno{1737}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from ‘Abdullah bin ‘Umar that the Day of ‘Ashura’ was mentioned in the presence of the Messenger of Allah (ﷺ). The Messenger of Allah (ﷺ) said:“That was a day when the people of the Ignorance used to fast. So whoever among you wants to fast may do so, and whoever does not want to may leave it.”}}
\hadithdefcmd{ibnmajah}{1738}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ، أَنْبَأَنَا حَمَّادُ بْنُ زَيْدٍ، حَدَّثَنَا غَيْلاَنُ بْنُ جَرِيرٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَعْبَدٍ الزِّمَّانِيِّ، عَنْ أَبِي قَتَادَةَ، قَالَ: قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ صِيَامُ يَوْمِ عَاشُورَاءَ إِنِّي أَحْتَسِبُ عَلَى اللَّهِ أَنْ يُكَفِّرَ السَّنَةَ الَّتِي قَبْلَهُ ‏"‏ ‏.‏\hadithno{1738}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Qatadah that the Messenger of Allah (ﷺ) said:“Fasting the day of ‘Ashura’, I hope, will expiate for the sins of the previous year.”}}
\hadithdefcmd{ibnmajah}{1739}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا يَحْيَى بْنُ حَمْزَةَ، حَدَّثَنِي ثَوْرُ بْنُ يَزِيدَ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنْ رَبِيعَةَ بْنِ الْغَازِ، أَنَّهُ سَأَلَ عَائِشَةَ عَنْ صِيَامِ، رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَتْ كَانَ يَتَحَرَّى صِيَامَ الاِثْنَيْنِ وَالْخَمِيسِ ‏.‏\hadithno{1739}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Rabi’ah bin Ghaz that he asked ‘Aishah about the fasting of the Messenger of Allah (ﷺ). She said:“He used to make sure he fasted on Mondays and Thursdays.”}}
\hadithdefcmd{ibnmajah}{1740}{حَدَّثَنَا الْعَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ الْعَنْبَرِيُّ، حَدَّثَنَا الضَّحَّاكُ بْنُ مَخْلَدٍ، عَنْ مُحَمَّدِ بْنِ رِفَاعَةَ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ يَصُومُ الاِثْنَيْنِ وَالْخَمِيسَ ‏.‏ فَقِيلَ يَا رَسُولَ اللَّهِ إِنَّكَ تَصُومُ يَوْمَ الاِثْنَيْنِ وَالْخَمِيسِ فَقَالَ ‏ "‏ إِنَّ يَوْمَ الاِثْنَيْنِ وَالْخَمِيسِ يَغْفِرُ اللَّهُ فِيهِمَا لِكُلِّ مُسْلِمٍ إِلاَّ مُهْتَجِرَيْنِ يَقُولُ دَعْهُمَا حَتَّى يَصْطَلِحَا ‏"‏ ‏.‏\hadithno{1740}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) used to fast on Mondays and Thursdays. It was said:“O Messenger of Allah, why do you fast on Mondays and Thursdays?” He said: “On Mondays and Thursdays Allah forgives every Muslim except two who have forsaken one another. He says: ‘Leave these two until they reconcile.’”}}
\hadithdefcmd{ibnmajah}{1741}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنِ الْجُرَيْرِيِّ، عَنْ أَبِي السَّلِيلِ، عَنْ أَبِي مُجِيبَةَ الْبَاهِلِيِّ، عَنْ أَبِيهِ، أَوْ عَنْ عَمِّهِ، قَالَ أَتَيْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ فَقُلْتُ يَا نَبِيَّ اللَّهِ أَنَا الرَّجُلُ الَّذِي أَتَيْتُكَ عَامَ الأَوَّلِ ‏.‏ قَالَ ‏"‏ فَمَا لِي أَرَى جِسْمَكَ نَاحِلاً ‏"‏ ‏.‏ قَالَ يَا رَسُولَ اللَّهِ مَا أَكَلْتُ طَعَامًا بِالنَّهَارِ مَا أَكَلْتُهُ إِلاَّ بِاللَّيْلِ ‏.‏ قَالَ ‏"‏ مَنْ أَمَرَكَ أَنْ تُعَذِّبَ نَفْسَكَ ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ إِنِّي أَقْوَى ‏.‏ قَالَ ‏"‏ صُمْ شَهْرَ الصَّبْرِ وَيَوْمًا بَعْدَهُ ‏.‏ قُلْتُ إِنِّي أَقْوَى ‏.‏ قَالَ ‏"‏ صُمْ شَهْرَ الصَّبْرِ وَيَوْمَيْنِ بَعْدَهُ ‏"‏ ‏.‏ قُلْتُ إِنِّي أَقْوَى ‏.‏ قَالَ ‏"‏ صُمْ شَهْرَ الصَّبْرِ وَثَلاَثَةَ أَيَّامٍ بَعْدَهُ وَصُمْ أَشْهُرَ الْحُرُمِ ‏"‏ ‏.‏\hadithno{1741}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Mujibah Al-Bahili that his father or, his paternal uncle, said:“I came to the Prophet (ﷺ) and said: ‘O Prophet of Allah, I am the man who came to you last year.’ He said: ‘Why do I see your body so thin (and weak)?’ He said: ‘O Messenger of Allah! I do not eat during the day; I only eat at night.’ He said: ‘Who commanded you to punish yourself?’ I said: ‘O Messenger of Allah! I am strong enough.’ He said: ‘Fast the month of patience* and one day after it.’ I said: ‘I am strong enough (to do more).’ He said: ‘Fast the month of patience and two days after it.’ I said: ‘I am strong enough (to do more).’ He said: ‘Fast the month of patience and three days after it, and fast the sacred months.’”}}
\hadithdefcmd{ibnmajah}{1742}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا الْحُسَيْنُ بْنُ عَلِيٍّ، عَنْ زَائِدَةَ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ مُحَمَّدِ بْنِ الْمُنْتَشِرِ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ الْحِمْيَرِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ فَقَالَ أَىُّ الصِّيَامِ أَفْضَلُ بَعْدَ شَهْرِ رَمَضَانَ قَالَ ‏ "‏ شَهْرُ اللَّهِ الَّذِي تَدْعُونَهُ الْمُحَرَّمَ ‏"‏ ‏.‏\hadithno{1742}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:“A man came to the Prophet (ﷺ) and said: ‘Which fasting is better after the month of Ramadan?’ He said: ‘The month of Allah which is called Muharram.’”}}
\hadithdefcmd{ibnmajah}{1743}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ الْحِزَامِيُّ، حَدَّثَنَا دَاوُدُ بْنُ عَطَاءٍ، حَدَّثَنِي زَيْدُ بْنُ عَبْدِ الْحَمِيدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ زَيْدِ بْنِ الْخَطَّابِ، عَنْ سُلَيْمَانَ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ نَهَى عَنْ صِيَامِ رَجَبٍ ‏.‏\hadithno{1743}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn ‘Abbas that:The Prophet (ﷺ) forbade fasting Rajab}}
\hadithdefcmd{ibnmajah}{1744}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، حَدَّثَنَا عَبْدُ الْعَزِيزِ الدَّرَاوَرْدِيُّ، عَنْ يَزِيدَ بْنِ عَبْدِ اللَّهِ بْنِ أُسَامَةَ بْنِ الْهَادِ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، أَنَّ أُسَامَةَ بْنَ زَيْدٍ، كَانَ يَصُومُ أَشْهُرَ الْحُرُمِ ‏.‏ فَقَالَ لَهُ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ صُمْ شَوَّالاً ‏"‏ ‏.‏ فَتَرَكَ أَشْهُرَ الْحُرُمِ ثُمَّ لَمْ يَزَلْ يَصُومُ شَوَّالاً حَتَّى مَاتَ ‏.‏\hadithno{1744}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Muhammad bin Ibrahim that Usamah bin Zaid used to fast the sacred months. The Messenger of Allah (ﷺ) said to him:“Fast Shawwal.” So he forsook the sacred months and he continued to fast Shawwal until he died}}
\hadithdefcmd{ibnmajah}{1745}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، ح وَحَدَّثَنَا مُحْرِزُ بْنُ سَلَمَةَ الْعَدَنِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، جَمِيعًا عَنْ مُوسَى بْنِ عُبَيْدَةَ، عَنْ جُمْهَانَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ لِكُلِّ شَىْءٍ زَكَاةٌ وَزَكَاةُ الْجَسَدِ الصَّوْمُ ‏"‏ ‏.‏ زَادَ مُحْرِزٌ فِي حَدِيثِهِ وَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ الصِّيَامُ نِصْفُ الصَّبْرِ ‏"‏ ‏.‏\hadithno{1745}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“For everything there is Zakat and the Zakat of the body is fasting.” (A narrator in one of the chains) Muhriz added in his narration: "And the Messenger of Allah (ﷺ) said: 'Fasting is half of patience}}
\hadithdefcmd{ibnmajah}{1746}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنِ ابْنِ أَبِي لَيْلَى، وَخَالِي، يَعْلَى عَنْ عَبْدِ الْمَلِكِ، وَأَبُو مُعَاوِيَةَ عَنْ حَجَّاجٍ، كُلُّهُمْ عَنْ عَطَاءٍ، عَنْ زَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ فَطَّرَ صَائِمًا كَانَ لَهُ مِثْلُ أَجْرِهِمْ مِنْ غَيْرِ أَنْ يَنْقُصَ مِنْ أُجُورِهِمْ شَيْئًا ‏"‏ ‏.‏\hadithno{1746}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Zaid bin Khalid Al-Juhani that the Messenger of Allah (ﷺ) said:“Whoever gives food for a fasting person to break his fast, he will have a reward like theirs, without that detracting from their reward in the slightest.”}}
\hadithdefcmd{ibnmajah}{1747}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سَعِيدُ بْنُ يَحْيَى اللَّخْمِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرٍو، عَنْ مُصْعَبِ بْنِ ثَابِتٍ، عَنْ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، قَالَ أَفْطَرَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عِنْدَ سَعْدِ بْنِ مُعَاذٍ فَقَالَ ‏ "‏ أَفْطَرَ عِنْدَكُمُ الصَّائِمُونَ وَأَكَلَ طَعَامَكُمُ الأَبْرَارُ وَصَلَّتْ عَلَيْكُمُ الْمَلاَئِكَةُ ‏"‏ ‏.‏\hadithno{1747}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Abdullah bin Zubair said:“The Messenger of Allah (ﷺ) broke his fast with Sa’d bin Mu’adh and said: ‘Aftara ‘indakumus-saimun, wa akala ta’amakumul-abrar, wa sallat ‘alaikumul- mala’ikah (May fasting people break their fast with you, may the righteous eat your food, and may the angels send blessing upon you).”}}
\hadithdefcmd{ibnmajah}{1748}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، وَسَهْلٌ، قَالُوا حَدَّثَنَا وَكِيعٌ، عَنْ شُعْبَةَ، عَنْ حَبِيبِ بْنِ زَيْدٍ الأَنْصَارِيِّ، عَنِ امْرَأَةٍ، يُقَالُ لَهَا لَيْلَى عَنْ أُمِّ عُمَارَةَ، قَالَتْ أَتَانَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَرَّبْنَا إِلَيْهِ طَعَامًا فَكَانَ بَعْضُ مَنْ عِنْدَهُ صَائِمًا فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الصَّائِمُ إِذَا أُكِلَ عِنْدَهُ الطَّعَامُ صَلَّتْ عَلَيْهِ الْمَلاَئِكَةُ ‏"‏ ‏.‏\hadithno{1748}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Umm ‘Umarah said:“The Messenger of Allah (ﷺ) came to us and we brought food for him. Some of those who were with him were fasting, and the Messenger of Allah (ﷺ) said: ‘If food is eaten in the presence of one who is fasting, the angels send blessing upon him.’”}}
\hadithdefcmd{ibnmajah}{1749}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُصَفَّى، حَدَّثَنَا بَقِيَّةُ، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ سُلَيْمَانَ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ لِبِلاَلٍ ‏"‏ الْغَدَاءُ يَا بِلاَلُ ‏"‏ ‏.‏ فَقَالَ إِنِّي صَائِمٌ ‏.‏ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ نَأْكُلُ أَرْزَاقَنَا وَفَضْلُ رِزْقِ بِلاَلٍ فِي الْجَنَّةِ أَشَعَرْتَ يَا بِلاَلُ أَنَّ الصَّائِمَ تُسَبِّحُ عِظَامُهُ وَتَسْتَغْفِرُ لَهُ الْمَلاَئِكَةُ مَا أُكِلَ عِنْدَهُ ‏"‏ ‏.‏\hadithno{1749}\hadithgrade{Al-Albani: Mawdu; Muhammad Fouad Abd al-Baqi: Mawdu; Shuaib Al Arnaut: Mawdu; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Sulaiman bin Buraidah that his father said:“The Messenger of Allah (ﷺ) said to Bilal: ‘Come and eat, O Bilal.’ He said: ‘I am fasting.’ The Messenger of Allah (ﷺ) said: ‘We are eating our provision, but most of Bilal’s provision is in Paradise. Do you realise, O Bilal, that the bones of the fasting person glorify Allah and the angels pray for forgiveness for him so long as food is eaten in front of him?’”}}
\hadithdefcmd{ibnmajah}{1750}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ الصَّبَّاحِ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِذَا دُعِيَ أَحَدُكُمْ إِلَى طَعَامٍ وَهُوَ صَائِمٌ فَلْيَقُلْ إِنِّي صَائِمٌ ‏"‏ ‏.‏\hadithno{1750}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:“If anyone of you is invited to eat when he is fasting, let him say: ‘I am fasting.’”}}
\hadithdefcmd{ibnmajah}{1751}{حَدَّثَنَا أَحْمَدُ بْنُ يُوسُفَ السُّلَمِيُّ، حَدَّثَنَا أَبُو عَاصِمٍ، أَنْبَأَنَا ابْنُ جُرَيْجٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ دُعِيَ إِلَى طَعَامٍ وَهُوَ صَائِمٌ فَلْيُجِبْ فَإِنْ شَاءَ طَعِمَ وَإِنْ شَاءَ تَرَكَ ‏"‏ ‏.‏\hadithno{1751}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Jabir that the Messenger of Allah (ﷺ) said:“Whoever is invited to eat when he is fasting, let him accept the invitation; and if he wants to let him eat, and if he wants let him not eat.”}}
\hadithdefcmd{ibnmajah}{1752}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ سَعْدَانَ الْجُهَنِيِّ، عَنْ سَعْدٍ أَبِي مُجَاهِدٍ الطَّائِيِّ، - وَكَانَ ثِقَةً - عَنْ أَبِي مُدِلَّةَ، - وَكَانَ ثِقَةً - عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ ثَلاَثَةٌ لاَ تُرَدُّ دَعْوَتُهُمُ الإِمَامُ الْعَادِلُ وَالصَّائِمُ حَتَّى يُفْطِرَ وَدَعْوَةُ الْمَظْلُومِ يَرْفَعُهَا اللَّهُ دُونَ الْغَمَامِ يَوْمَ الْقِيَامَةِ وَتُفْتَحُ لَهَا أَبْوَابُ السَّمَاءِ وَيَقُولُ بِعِزَّتِي لأَنْصُرَنَّكِ وَلَوْ بَعْدَ حِينٍ ‏"‏ ‏.‏\hadithno{1752}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:There are three whose supplications are not turned back: A just ruler, and a fasting person until he breaks his fast. And, the supplication of one who has been wronged is raised by Allah up to the clouds on the Day of Resurrection, and the gates of heaven are opened for it, and Allah says, ‘By My Might I will help you (against the wrongdoer) even if it is after a while.’”}}
\hadithdefcmd{ibnmajah}{1753}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا إِسْحَاقُ بْنُ عُبَيْدِ اللَّهِ الْمَدَنِيُّ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ أَبِي مُلَيْكَةَ، يَقُولُ سَمِعْتُ عَبْدَ اللَّهِ بْنَ عَمْرِو بْنِ الْعَاصِ، يَقُولُ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ لِلصَّائِمِ عِنْدَ فِطْرِهِ لَدَعْوَةً مَا تُرَدُّ ‏"‏ ‏.‏ قَالَ ابْنُ أَبِي مُلَيْكَةَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ عَمْرٍو يَقُولُ إِذَا أَفْطَرَ اللَّهُمَّ إِنِّي أَسْأَلُكَ بِرَحْمَتِكَ الَّتِي وَسِعَتْ كُلَّ شَىْءٍ أَنْ تَغْفِرَ لِي ‏.‏\hadithno{1753}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from ‘Abdullah bin ‘Amr bin ‘As that the Messenger of Allah (ﷺ) said:“When the fasting person breaks his fast, his supplication is not turned back.” (One of the narrators) Ibn Abi Mulaikah said: "When he broke his fast, I heard 'Abdullah bin 'Amr say: 'O Allah! I ask You by Your mercy, which encompasses all things, to forgive me}}
\hadithdefcmd{ibnmajah}{1754}{حَدَّثَنَا جُبَارَةُ بْنُ الْمُغَلِّسِ، حَدَّثَنَا هُشَيْمٌ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ لاَ يَخْرُجُ يَوْمَ الْفِطْرِ حَتَّى يَطْعَمَ تَمَرَاتٍ ‏.‏\hadithno{1754}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Anas bin Malik said:“The Prophet (ﷺ) would not go out on the Day of Fitr until he had eaten some dates.”}}
\hadithdefcmd{ibnmajah}{1755}{حَدَّثَنَا جُبَارَةُ بْنُ الْمُغَلِّسِ، حَدَّثَنَا مِنْدَلُ بْنُ عَلِيٍّ، حَدَّثَنَا عُمَرُ بْنُ صُهْبَانَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ لاَ يَغْدُو يَوْمَ الْفِطْرِ حَتَّى يُغَدِّيَ أَصْحَابَهُ مِنْ صَدَقَةِ الْفِطْرِ ‏.‏\hadithno{1755}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn ‘Umar said:“The Prophet (ﷺ) would not go out on the Day of Fitr until he had had given his Companions some of the charity of Fitr to eat.”}}
\hadithdefcmd{ibnmajah}{1756}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا أَبُو عَاصِمٍ، حَدَّثَنَا ثَوَابُ بْنُ عُتْبَةَ الْمَهْرِيُّ، عَنِ ابْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ لاَ يَخْرُجُ يَوْمَ الْفِطْرِ حَتَّى يَأْكُلَ وَكَانَ لاَ يَأْكُلُ يَوْمَ النَّحْرِ حَتَّى يَرْجِعَ ‏.‏\hadithno{1756}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Ibn Buraidah from his father, that:The Messenger of Allah (ﷺ) would not go out on the Day of Fitr until he had eaten, and he would not eat on the Day of Nahr (the day of sacrifice) until he came back}}
\hadithdefcmd{ibnmajah}{1757}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْثَرٌ، عَنْ أَشْعَثَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ مَاتَ وَعَلَيْهِ صِيَامُ شَهْرٍ فَلْيُطْعَمْ عَنْهُ مَكَانَ كُلِّ يَوْمٍ مِسْكِينٌ ‏"‏ ‏.‏\hadithno{1757}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn ‘Umar that the Messenger of Allah (ﷺ) said:‘Whoever dies owing the fasts of a month, one poor person should be fed on his behalf for each day.”}}
\hadithdefcmd{ibnmajah}{1758}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنِ الأَعْمَشِ، عَنْ مُسْلِمٍ الْبَطِينِ، وَالْحَكَمِ، وَسَلَمَةَ بْنِ كُهَيْلٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، وَعَطَاءٍ، وَمُجَاهِدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ جَاءَتِ امْرَأَةٌ إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ أُخْتِي مَاتَتْ وَعَلَيْهَا صِيَامُ شَهْرَيْنِ مُتَتَابِعَيْنِ قَالَ ‏"‏ أَرَأَيْتِ لَوْ كَانَ عَلَى أُخْتِكِ دَيْنٌ أَكُنْتِ تَقْضِينَهُ ‏"‏ ‏.‏ قَالَتْ بَلَى ‏.‏ قَالَ ‏"‏ فَحَقُّ اللَّهِ أَحَقُّ ‏"‏ ‏.‏\hadithno{1758}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Ibn ‘Abbas said:“A woman came to the Prophet (ﷺ) and said: ‘O Messenger of Allah, my sister has died and she owed a fast of two consecutive months.’ He said: ‘Do you not think that if your sister owed a debt, you would pay it off for her?’ She said: ‘Of course.’ He said: ‘The right of Allah is greater.’”}}
\hadithdefcmd{ibnmajah}{1759}{حَدَّثَنَا زُهَيْرُ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ سُفْيَانَ، عَنْ عَبْدِ اللَّهِ بْنِ عَطَاءٍ، عَنِ ابْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ جَاءَتِ امْرَأَةٌ إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ أُمِّي مَاتَتْ وَعَلَيْهَا صَوْمٌ أَفَأَصُومُ عَنْهَا قَالَ ‏ "‏ نَعَمْ ‏"‏ ‏.‏\hadithno{1759}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn Buraidah that his father said:“A woman came to the Prophet (ﷺ) and said: ‘O Messenger of Allah, my mother has died and she owed a fast. Should I fast on her behalf?’ He said: ‘Yes.’”}}
\hadithdefcmd{ibnmajah}{1760}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا أَحْمَدُ بْنُ خَالِدٍ الْوَهْبِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ إِسْحَاقَ، عَنْ عِيسَى بْنِ عَبْدِ اللَّهِ بْنِ مَالِكٍ، عَنْ عَطِيَّةَ بْنِ سُفْيَانَ بْنِ عَبْدِ اللَّهِ بْنِ رَبِيعَةَ، قَالَ حَدَّثَنَا وَفْدُنَا الَّذِينَ، قَدِمُوا عَلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ بِإِسْلاَمِ ثَقِيفٍ ‏.‏ قَالَ وَقَدِمُوا عَلَيْهِ فِي رَمَضَانَ وَضَرَبَ عَلَيْهِمْ قُبَّةً فِي الْمَسْجِدِ فَلَمَّا أَسْلَمُوا صَامُوا مَا بَقِيَ عَلَيْهِمْ مِنَ الشَّهْرِ ‏.‏\hadithno{1760}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Atiyyah bin Sufyan bin ‘Abdullah bin Rabi’ah said:“Our delegation who went to the Messenger of Allah (ﷺ) to announce the Islam of Thaqif told us that they came to him in Ramadan. He set up a tent for them in the mosque, and when they became Muslim, they fasted what was left of the month.”}}
\hadithdefcmd{ibnmajah}{1761}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ تَصُومُ الْمَرْأَةُ وَزَوْجُهَا شَاهِدٌ يَوْمًا مِنْ غَيْرِ شَهْرِ رَمَضَانَ إِلاَّ بِإِذْنِهِ ‏"‏ ‏.‏\hadithno{1761}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:“When her husband is present, no woman should fast any day apart from the month of Ramadan without his permission.”}}
\hadithdefcmd{ibnmajah}{1762}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا يَحْيَى بْنُ حَمَّادٍ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ سُلَيْمَانَ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي سَعِيدٍ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ النِّسَاءَ أَنْ يَصُمْنَ إِلاَّ بِإِذْنِ أَزْوَاجِهِنَّ ‏.‏\hadithno{1762}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Sa’eed said:“The Messenger of Allah (ﷺ) forbade women from fasting without the permission of their husbands.”}}
\hadithdefcmd{ibnmajah}{1763}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى الأَزْدِيُّ، حَدَّثَنَا مُوسَى بْنُ دَاوُدَ، وَخَالِدُ بْنُ أَبِي يَزِيدَ، قَالاَ حَدَّثَنَا أَبُو بَكْرٍ الْمَدَنِيُّ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِذَا نَزَلَ الرَّجُلُ بِقَوْمٍ فَلاَ يَصُومُ إِلاَّ بِإِذْنِهِمْ ‏"‏ ‏.‏\hadithno{1763}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Aishah that the Prophet (ﷺ) said:“If a man stays among a people, he should not fast without their permission.”}}
\hadithdefcmd{ibnmajah}{1764}{حَدَّثَنَا يَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، حَدَّثَنَا مُحَمَّدُ بْنُ مَعْنٍ، عَنْ أَبِيهِ، وَعَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ الأُمَوِيِّ، عَنْ مَعْنِ بْنِ مُحَمَّدٍ، عَنْ حَنْظَلَةَ بْنِ عَلِيٍّ الأَسْلَمِيِّ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ أَنَّهُ قَالَ ‏ "‏ الطَّاعِمُ الشَّاكِرُ بِمَنْزِلَةِ الصَّائِمِ الصَّابِرِ ‏"‏ ‏.‏\hadithno{1764}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:“A grateful eater is equal to a patient fasting person.”}}
\hadithdefcmd{ibnmajah}{1765}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَبْدِ اللَّهِ الرَّقِّيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ جَعْفَرٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ مُحَمَّدِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي حُرَّةَ، عَنْ عَمِّهِ، حَكِيمِ بْنِ أَبِي حُرَّةَ عَنْ سِنَانِ بْنِ سَنَّةَ الأَسْلَمِيِّ، صَاحِبِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الطَّاعِمُ الشَّاكِرُ لَهُ مِثْلُ أَجْرِ الصَّائِمِ الصَّابِرِ ‏"‏ ‏.‏\hadithno{1765}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Sinan bin Sannah Al-Aslami, the Companion of the Prophet (ﷺ), that the Messenger of Allah (ﷺ) said:“A grateful eater will have a reward like that of a patient fasting person.”}}
\hadithdefcmd{ibnmajah}{1766}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ هِشَامٍ الدَّسْتَوَائِيِّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ اعْتَكَفْنَا مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ الْعَشْرَ الأَوْسَطَ مِنْ رَمَضَانَ فَقَالَ ‏ "‏ إِنِّي أُرِيتُ لَيْلَةَ الْقَدْرِ فَأُنْسِيتُهَا فَالْتَمِسُوهَا فِي الْعَشْرِ الأَوَاخِرِ فِي الْوَتْرِ ‏"‏ ‏.‏\hadithno{1766}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Abu Sa’eed Al-Khudri said:“We observed I’tikaf with the Messenger of Allah (ﷺ) during the middle ten days of Ramadan. He said: ‘I have been shown Lailatul-Qadr, then I was caused to forget it, so seek it in the last ten night, on the odd-numbered nights.’”}}
\hadithdefcmd{ibnmajah}{1767}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي الشَّوَارِبِ، وَأَبُو إِسْحَاقَ الْهَرَوِيُّ إِبْرَاهِيمُ بْنُ عَبْدِ اللَّهِ بْنِ حَاتِمٍ قَالاَ حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، حَدَّثَنَا الْحَسَنُ بْنُ عُبَيْدِ اللَّهِ، عَنْ إِبْرَاهِيمَ النَّخَعِيِّ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ يَجْتَهِدُ فِي الْعَشْرِ الأَوَاخِرِ مَا لاَ يَجْتَهِدُ فِي غَيْرِهِ ‏.‏\hadithno{1767}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that ‘Aishah said:“The Prophet (ﷺ) used to strive hard (in worship) in the last ten nights of Ramadan as he never did at any other time.”}}
\hadithdefcmd{ibnmajah}{1768}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ الزُّهْرِيُّ، حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ عُبَيْدِ بْنِ نِسْطَاسٍ، عَنْ أَبِي الضُّحَى، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ إِذَا دَخَلَتِ الْعَشْرُ أَحْيَا اللَّيْلَ وَشَدَّ الْمِئْزَرَ وَأَيْقَظَ أَهْلَهُ ‏.‏\hadithno{1768}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that ‘Aishah said:“When the last ten days of Ramadan began, the Prophet (ﷺ) used to stay up at night, tighten his waist- wrap, and wake up his family (to pray).”}}
\hadithdefcmd{ibnmajah}{1769}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنْ أَبِي حُصَيْنٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ يَعْتَكِفُ كُلَّ عَامٍ عَشْرَةَ أَيَّامٍ فَلَمَّا كَانَ الْعَامُ الَّذِي قُبِضَ فِيهِ اعْتَكَفَ عِشْرِينَ يَوْمًا وَكَانَ يُعْرَضُ عَلَيْهِ الْقُرْآنُ فِي كُلِّ عَامٍ مَرَّةً فَلَمَّا كَانَ الْعَامُ الَّذِي قُبِضَ فِيهِ عُرِضَ عَلَيْهِ مَرَّتَيْنِ ‏.‏\hadithno{1769}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Abu Hurairah said:“The Prophet (ﷺ) used to observe I’tikaf for ten days every year. In the year in which he passed away, he observed I’tikaf for twenty days. And the Qur’an would be reviewed with him once every year, but in the year in which he passed away, it was reviewed with him twice.”}}
\hadithdefcmd{ibnmajah}{1770}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ ثَابِتٍ، عَنْ أَبِي رَافِعٍ، عَنْ أُبَىِّ بْنِ كَعْبٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ يَعْتَكِفُ الْعَشْرَ الأَوَاخِرَ مِنْ رَمَضَانَ فَسَافَرَ عَامًا فَلَمَّا كَانَ مِنَ الْعَامِ الْمُقْبِلِ اعْتَكَفَ عِشْرِينَ يَوْمًا ‏.‏\hadithno{1770}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ubayy bin Ka’b that:The Prophet (ﷺ) used to spend the last ten days of Ramadan in I’tikaf. One year he was traveling, so the following year he spent twenty days in I’tikaf}}
\hadithdefcmd{ibnmajah}{1771}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَعْلَى بْنُ عُبَيْدٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ إِذَا أَرَادَ أَنْ يَعْتَكِفَ صَلَّى الصُّبْحَ ثُمَّ دَخَلَ الْمَكَانَ الَّذِي يُرِيدُ أَنْ يَعْتَكِفَ فِيهِ فَأَرَادَ أَنْ يَعْتَكِفَ الْعَشْرَ الأَوَاخِرَ مِنْ رَمَضَانَ فَأَمَرَ فَضُرِبَ لَهُ خِبَاءٌ فَأَمَرَتْ عَائِشَةُ بِخِبَاءٍ فَضُرِبَ لَهَا وَأَمَرَتْ حَفْصَةُ بِخِبَاءٍ فَضُرِبَ لَهَا فَلَمَّا رَأَتْ زَيْنَبُ خِبَاءَهُمَا أَمَرَتْ بِخِبَاءٍ فَضُرِبَ لَهَا فَلَمَّا رَأَى ذَلِكَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ آلْبِرَّ تُرِدْنَ ‏"‏ ‏.‏ فَلَمْ يَعْتَكِفْ فِي رَمَضَانَ وَاعْتَكَفَ عَشْرًا مِنْ شَوَّالٍ ‏.‏\hadithno{1771}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that ‘Aishah said:“When the Prophet (ﷺ) wanted to start I’tikaf, he would pray the Subh, then he would enter the place where he wanted to observe I’tikaf. He wanted to spend the last ten days of Ramadan in I’tikaf, so he ordered that a tent be set up for him.” Then ‘Aishah ordered that a tent be set up for her, and Hafash ordered that a tent be set up for her. When Zainab saw their two tents, she also ordered that a tent be set up for her. When the Messenger of Allah (ﷺ) saw that, he said: “It is righteousness that you seek?” Then he did not observe I’tikaf during Ramadan, and he observed I’tikaf during ten days of Shawwal}}
\hadithdefcmd{ibnmajah}{1772}{حَدَّثَنَا إِسْحَاقُ بْنُ مُوسَى الْخَطْمِيُّ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنْ عُمَرَ، أَنَّهُ كَانَ عَلَيْهِ نَذْرُ لَيْلَةٍ فِي الْجَاهِلِيَّةِ يَعْتَكِفُهَا فَسَأَلَ النَّبِيَّ ـ صلى الله عليه وسلم ـ فَأَمَرَهُ أَنْ يَعْتَكِفَ ‏.‏\hadithno{1772}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from ‘Umar that he had vowed during the days of Ignorance to spend one night in I’tikaf. He asked the Prophet (ﷺ) about it, so he commanded him to spend it in I’tikaf}}
\hadithdefcmd{ibnmajah}{1773}{حَدَّثَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَنْبَأَنَا يُونُسُ، أَنَّ نَافِعًا، حَدَّثَهُ عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ يَعْتَكِفُ الْعَشْرَ الأَوَاخِرَ مِنْ رَمَضَانَ ‏.‏ قَالَ نَافِعٌ وَقَدْ أَرَانِي عَبْدُ اللَّهِ بْنُ عُمَرَ الْمَكَانَ الَّذِي كَانَ يَعْتَكِفُ فِيهِ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏\hadithno{1773}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from ‘Abdullah bin ‘Umar that:The Messenger of Allah (ﷺ) used to spend the last ten days of Ramadan in I’tikaf. Nafi' said: " Abdullah bin 'Umar showed me the place where the Messenger of Allah (ﷺ) used to observe I'tikaf}}
\hadithdefcmd{ibnmajah}{1774}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا نُعَيْمُ بْنُ حَمَّادٍ، حَدَّثَنَا ابْنُ الْمُبَارَكِ، عَنْ عِيسَى بْنِ عُمَرَ بْنِ مُوسَى، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ أَنَّهُ كَانَ إِذَا اعْتَكَفَ طُرِحَ لَهُ فِرَاشُهُ - أَوْ يُوضَعُ لَهُ سَرِيرُهُ وَرَاءَ أُصْطُوَانَةِ التَّوْبَةِ ‏.‏\hadithno{1774}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Ibn ‘Umar that:When the Prophet (ﷺ) observed I’tikaf, his bedding would be spread for him, or his bed would be placed there for him, behind the Pillar of Repentance}}
\hadithdefcmd{ibnmajah}{1775}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى الصَّنْعَانِيُّ، حَدَّثَنَا الْمُعْتَمِرُ بْنُ سُلَيْمَانَ، حَدَّثَنِي عُمَارَةُ بْنُ غَزِيَّةَ، قَالَ سَمِعْتُ مُحَمَّدَ بْنَ إِبْرَاهِيمَ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ اعْتَكَفَ فِي قُبَّةٍ تُرْكِيَّةٍ عَلَى سُدَّتِهَا قِطْعَةُ حَصِيرٍ ‏.‏ قَالَ فَأَخَذَ الْحَصِيرَ بِيَدِهِ فَنَحَّاهَا فِي نَاحِيَةِ الْقُبَّةِ ثُمَّ أَطْلَعَ رَأْسَهُ فَكَلَّمَ النَّاسَ ‏.‏\hadithno{1775}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Sa’eed Al-Khudri that:The Messenger of Allah (ﷺ) observed I’tifak in a Turkish tent, over the door of which was a piece of reed matting. He pushed the mat aside, then he put his head out and spoke to the people}}
\hadithdefcmd{ibnmajah}{1776}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، وَعَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، أَنَّ عَائِشَةَ، قَالَتْ إِنْ كُنْتُ لأَدْخُلُ الْبَيْتَ لِلْحَاجَةِ وَالْمَرِيضُ فِيهِ فَمَا أَسْأَلُ عَنْهُ إِلاَّ وَأَنَا مَارَّةٌ ‏.‏ قَالَتْ وَكَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ لاَ يَدْخُلُ الْبَيْتَ إِلاَّ لِحَاجَةٍ إِذَا كَانُوا مُعْتَكِفِينَ ‏.‏\hadithno{1776}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that ‘Aishah said:“I used to enter the house to relieve myself, and there was a sick person there, and I only inquired after him as I was passing through.” She said: “And the Messenger of Allah (ﷺ) would not enter the house except to relieve himself, then they were observing I’tikaf.”}}
\hadithdefcmd{ibnmajah}{1777}{حَدَّثَنَا أَحْمَدُ بْنُ مَنْصُورٍ أَبُو بَكْرٍ، حَدَّثَنَا يُونُسُ بْنُ مُحَمَّدٍ، حَدَّثَنَا الْهَيَّاجُ الْخُرَاسَانِيُّ، حَدَّثَنَا عَنْبَسَةُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ عَبْدِ الْخَالِقِ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الْمُعْتَكِفُ يَتْبَعُ الْجِنَازَةَ وَيَعُودُ الْمَرِيضَ ‏"‏ ‏.‏\hadithno{1777}\hadithgrade{Al-Albani: Mawdu; Muhammad Fouad Abd al-Baqi: Mawdu; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Anas bin Malik said:“The Messenger of Allah (ﷺ) said: ‘The person observing I’tikaf may attend funerals and visit the sick.’”}}
\hadithdefcmd{ibnmajah}{1778}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يُدْنِي إِلَىَّ رَأْسَهُ وَهُوَ مُجَاوِرٌ فَأَغْسِلُهُ وَأُرَجِّلُهُ وَأَنَا فِي حُجْرَتِي وَأَنَا حَائِضٌ وَهُوَ فِي الْمَسْجِدِ ‏.‏\hadithno{1778}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that ‘Aishah said:“The Messenger of Allah (ﷺ) used to bring his head towards me when he was next door (observing I’tikaf), and I would wash it and comb his hair, when I was in my apartment and I was menstruating, and he was in the mosque.”}}
\hadithdefcmd{ibnmajah}{1779}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ الْحِزَامِيُّ، حَدَّثَنَا عُمَرُ بْنُ عُثْمَانَ بْنِ عُمَرَ بْنِ مُوسَى بْنِ عُبَيْدِ اللَّهِ بْنِ مَعْمَرٍ، عَنْ أَبِيهِ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي عَلِيُّ بْنُ الْحُسَيْنِ، عَنْ صَفِيَّةَ بِنْتِ حُيَىٍّ، زَوْجِ النَّبِيِّ ـ صلى الله عليه وسلم ـ أَنَّهَا جَاءَتْ إِلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ تَزُورُهُ وَهُوَ مُعْتَكِفٌ فِي الْمَسْجِدِ فِي الْعَشْرِ الأَوَاخِرِ مِنْ شَهْرِ رَمَضَانَ فَتَحَدَّثَتْ عِنْدَهُ سَاعَةً مِنَ الْعِشَاءِ ثُمَّ قَامَتْ تَنْقَلِبُ فَقَامَ مَعَهَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَقْلِبُهَا حَتَّى إِذَا بَلَغَتْ بَابَ الْمَسْجِدِ الَّذِي كَانَ عِنْدَ مَسْكَنِ أُمِّ سَلَمَةَ زَوْجِ النَّبِيِّ ـ صلى الله عليه وسلم ـ مَرَّ بِهِمَا رَجُلاَنِ مِنَ الأَنْصَارِ فَسَلَّمَا عَلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ثُمَّ نَفَذَا فَقَالَ لَهُمَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ عَلَى رِسْلِكُمَا إِنَّهَا صَفِيَّةُ بِنْتُ حُيَىٍّ ‏"‏ ‏.‏ قَالاَ سُبْحَانَ اللَّهِ يَا رَسُولَ اللَّهِ وَكَبُرَ عَلَيْهِمَا ذَلِكَ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ إِنَّ الشَّيْطَانَ يَجْرِي مِنِ ابْنِ آدَمَ مَجْرَى الدَّمِ وَإِنِّي خَشِيتُ أَنْ يَقْذِفَ فِي قُلُوبِكُمَا شَيْئًا ‏"‏ ‏.‏\hadithno{1779}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Safiyyah bint Huyai, the wife of the Prophet (ﷺ), that she came to visit the Messenger of Allah (ﷺ) when he was in I’tikaf during the last ten days of the month of Ramadan. She spoke with him for a while during the evening, then she stood up to go back. The Messenger of Allah (ﷺ) got up to take her home. When she reached the door of the mosque that was by the home of Umm Salamah, the wife of the Prophet (ﷺ), two men from among the Ansar passed by them. They greeted the Messenger of Allah (ﷺ) with peace, then went away. The Messenger of Allah (ﷺ) said:“Take it easy, she is Safiyyah bint Huyai.” They said: “Glorious is Allah, O Messenger of Allah!” And they were very upset by that (i.e., that he thought they may have some doubts). The Messenger of Allah (ﷺ) said: “The Satan flows through the son of Adam like blood, and I was afraid that he might cast some doubt into your hearts.”}}
\hadithdefcmd{ibnmajah}{1780}{حَدَّثَنَا الْحَسَنُ بْنُ مُحَمَّدِ بْنِ الصَّبَّاحِ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ عِكْرِمَةَ، قَالَ قَالَتْ عَائِشَةُ اعْتَكَفَتْ مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ امْرَأَةٌ مِنْ نِسَائِهِ فَكَانَتْ تَرَى الْحُمْرَةَ وَالصُّفْرَةَ فَرُبَّمَا وَضَعَتْ تَحْتَهَا الطَّسْتَ ‏.‏\hadithno{1780}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{‘Aishah said:“One of the wives of the Messenger of Allah (ﷺ) observed I’tikaf with him, and she used to see red and yellow discharge, and sometime she would put a basin beneath her.”}}
\hadithdefcmd{ibnmajah}{1781}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عَبْدِ الْكَرِيمِ، حَدَّثَنَا مُحَمَّدُ بْنُ أُمَيَّةَ، حَدَّثَنَا عِيسَى بْنُ مُوسَى الْبُخَارِيُّ، عَنْ عَبِيدَةَ الْعَمِّيِّ، عَنْ فَرْقَدٍ السَّبَخِيِّ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ فِي الْمُعْتَكِفِ ‏ "‏ هُوَ يَعْكِفُ الذُّنُوبَ وَيُجْرَى لَهُ مِنَ الْحَسَنَاتِ كَعَامِلِ الْحَسَنَاتِ كُلِّهَا ‏"‏ ‏.‏\hadithno{1781}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn ‘Abbas that:The Messenger of Allah (ﷺ) said concerning the person observing I’tikaf. “He is refraining from sin and he will be given a reward like that of one who does all kinds of good deeds.”}}
\hadithdefcmd{ibnmajah}{1782}{حَدَّثَنَا أَبُو أَحْمَدَ الْمَرَّارُ بْنُ حَمُّويَهْ، حَدَّثَنَا مُحَمَّدُ بْنُ الْمُصَفَّى، حَدَّثَنَا بَقِيَّةُ بْنُ الْوَلِيدِ، عَنْ ثَوْرِ بْنِ يَزِيدَ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنْ أَبِي أُمَامَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ قَامَ لَيْلَتَىِ الْعِيدَيْنِ لِلَّهِ مُحْتَسِبًا لَمْ يَمُتْ قَلْبُهُ يَوْمَ تَمُوتُ الْقُلُوبُ ‏"‏ ‏.‏\hadithno{1782}\hadithgrade{Al-Albani: Mawdu; Muhammad Fouad Abd al-Baqi: Mawdu; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Umamah that the Prophet (ﷺ) said:“Whoever spends the nights of the two ‘Eid in praying voluntary prayers, seeking reward from Allah, his heart will not die on the Day when hearts will die.”}}
